/*----------- REXX : STRIP ----------------------------------*/ 
/*                                                           */ 
/* This Process reads an  input file and extract out the     */ 
/* lines statistics found on particular lines                */ 
/*                                                           */ 
/* The input is from the query of the Software_Event_Log     */ 
/* for entries related to Mini-Cyl Packs and PackDisk.       */ 
/*                                                           */ 
/* The runtime parameters are:                               */ 
/*   (1) Input File Name                                     */ 
/*   (2) Output File Name                                    */ 
/*                                                           */ 
/*-----------------------------------------------------------*/ 

ADDRESS TSO 
TRACE N 

ARG Args 
PARSE UPPER VAR Args iFileName oFileName . 

IF oFileName = '' THEN DO 
  "CLEAR" 
  DO I = 1 TO SourceLine() 
    IF SUBSTR(SourceLine(I), 1, 2) = '/*' THEN 
      SAY STRIP(SourceLine(I), 'B') 
    ELSE 
      LEAVE 
    END 
  EXIT 
  END 

IF LISTDSI(iFileName) <> 0 THEN DO 
  SAY 'Invalid input file name: "'iFileName'" not found'; 
  EXIT 
  END 

"ALLOC DDN(iFile) SHR DSN("iFileName") REUSE" 
IF LISTDSI(oFileName) <> 0 THEN 
  "ALLOC DDN(oFile) NEW SPACE(10,10) TRACKS DIR(0) DSN("oFileName") REUSE" 
ELSE 
  "ALLOC DDN(oFile) SHR DSN("oFileName") REUSE" 

inputRows   = 0 
outputRows  = 0 
saveDate    = '' 
saveEvent   = '' 
"EXECIO 3 DISKR iFile (STEM Line.)"    /* Bypass Headings */ 
QUEUE "@@@CylPack at Cylinders@Cylinders at CylPack@Cylinders" 
QUEUE "Date at Event Tag at Events@Performed at Scanned@Freed at Failures@Allocated" 

DO FOREVER 
  "EXECIO 1000 DISKR iFile (STEM Line.)" 
  IF Line.0 = 0 THEN DO 
    QUEUE saveDate"@"saveEvent"@"Cnt.0"@"Cnt.1"@"Cnt.2"@"Cnt.3"@"Cnt.4"@"Cnt.6 
    LEAVE 
    END 
  inputRows = inputRows + Line.0 
  DO I = 1 TO Line.0 
    PARSE VAR Line.I Word.1 Word.2 Word.3 Word.4 Word.5 Word.6 Word.7 Word.8 Word.9 Word.10 Word.11 . 
    IF Word.1 <> saveDate THEN DO 
      IF saveDate <> '' THEN 
        QUEUE saveDate"@"saveEvent"@"Cnt.0"@"Cnt.1"@"Cnt.2"@"Cnt.3"@"Cnt.4"@"Cnt.6 
      saveDate  = Word.1 
      saveEvent = '' 
      END 
    IF Word.2 <> saveEvent THEN DO 
      IF saveEvent <> '' THEN 
        QUEUE saveDate"@"saveEvent"@"Cnt.0"@"Cnt.1"@"Cnt.2"@"Cnt.3"@"Cnt.4"@"Cnt.6 
      saveEvent = Word.2 
      Cnt.0 = 0; 
      Cnt.1 = 0; 
      Cnt.2 = 0; 
      Cnt.3 = 0; 
      Cnt.4 = 0; 
      Cnt.5 = 0; 
      Cnt.6 = 0; 
      END 
    Cnt.0 = Cnt.0 + 1 
    SELECT 
      WHEN saveEvent = '34-05141-00' THEN DO 
        Cnt.1 = Cnt.1 + Word.4 
        Cnt.2 = Cnt.2 + Word.8 
        Cnt.3 = Cnt.3 + Word.11 
        END 
      WHEN saveEvent = '34-05142-00' THEN DO 
        Cnt.1 = Cnt.1 + Word.4 
        Cnt.2 = Cnt.2 + Word.8 
        Cnt.3 = Cnt.3 + Word.11 
        END 
      WHEN saveEvent = '34-05143-00' THEN DO 
        IF Word.3 = '3' THEN DO 
          Cnt.1 = Cnt.1 + Word.4 
          Cnt.2 = Cnt.2 + Word.8 
          Cnt.3 = Cnt.3 + Word.11 
          END 
        ELSE DO 
          Cnt.4 = Cnt.4 + Word.4 
          Cnt.0 = Cnt.0 - 1            /* Don't count second card */ 
          END 
        END 
      WHEN saveEvent = '34-05144-00' THEN DO 
        PARSE UPPER VAR Word.10 percentFree '%' . 
        IF percentFree <> 'SPACE' THEN 
          Cnt.5 = Cnt.5 + (percentFree / 100.00) 
        END 
      WHEN saveEvent = '34-05145-00' THEN DO 
        Cnt.2 = Cnt.2 + Word.4 
        Cnt.6 = Cnt.6 + Word.7 
        END 
      WHEN saveEvent = '34-05146-00' THEN DO 
        Cnt.1 = Cnt.1 + Word.4 
        Cnt.2 = Cnt.2 + Word.7 
        END 
      OTHERWISE     NOP 
      END 
    END 
  outputRows = outputRows + QUEUED() 
  "EXECIO "QUEUED()" DISKW oFile" 
  SAY inputRows" have been processed." 
  END 

outputRows = outputRows + QUEUED() 

"EXECIO 0 DISKR iFile (FINIS)" 
"EXECIO "QUEUED()" DISKW oFile (FINIS)" 
"FREE DDN(iFile, oFile)" 

SAY "Processed: "inputRows" Input,  "outputRows" Output." 

EXIT 
