/*----- REXX:  HUTCNS Utility ----------------------------------*/ 
/*                                                              */ 
/*   Run Teradata HUTCNS Utility with the following Params:     */ 
/*     (1) Logon_ID                                             */ 
/*     (2) Run_Option - 1=Fore,2=Back,3=BldJCL & Edit           */ 
/*                                                              */ 
/*--------------------------------------------------------------*/ 

ADDRESS ISREDIT "MACRO (PARM1)" 
ADDRESS ISREDIT "(FLINE) = LINENUM .ZFIRST" 
ADDRESS ISREDIT "(LLINE) = LINENUM .ZLAST" 
ADDRESS ISREDIT "(MEMBR) = MEMBER" 
CALL LOADBTEQ 

IF PARM1 = "" THEN DO 
   LOGON_ID = CHOOSELOGON() 
   END 
ELSE DO 
   DO WHILE INDEX(PARM1, ',') <> 0 
      PARSE VAR PARM1 X1 ',' X2 
      PARM1 = X1" "X2 
      END 

   PARSE VAR PARM1 LOGON_ID RUN_OPTN . 

SELECT 
   WHEN RUN_OPTN = 1 THEN  CALL RUNFOREGROUND 
   WHEN RUN_OPTN = 2 THEN  CALL RUNBACKGROUND 
   OTHERWISE 
      SAY 'Invalid Run Option Selected (Must be 1 or 2)' 
   END 
RETURN 

/*--------------------- RUN BTEQ IN FOREGROUND ----------------------*/ 
RUNFOREGROUND: 
   "CLEAR" 
   SAY CENTER("GENERATE HUTCNS COMMANDS",80) 
   SAY "" 

   "NEWSTACK" 
   FILEID = "BTEQ"RIGHT("0000"RANDOM(1,9999),4) 
   FATTR  = "NEW SPACE(10,10) TRACKS DIR(0) REUSE" 
   "ALLOC DDN(output)   "FATTR" DSN("FILEID".HUTCNS)" 
   "ALLOC DDN(input)    "FATTR" DSN("FILEID".SCRIPT)" 
   "ALLOC DDN(sysprint) SHR DSN(*) REUSE" 

   "ALLOC DDN(logon) SHR DSN("Logon.Logon_ID.Member") REUSE" 
   "EXECIO * DISKR logon (STEM Line. FINIS)" 
   PARSE UPPER VAR Line.1 . "LOGON" Line.1 ";" . 
   QUEUE STRIP(Line.1, 'B') 
   "FREE  DDN(logon)" 

   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(xline) = LINE "I" " 
      QUEUE STRIP(xline, 'T') 
      END 

   QUEUE "END" 
   "EXECIO" QUEUED() "DISKW input (FINIS)" 

   SAY "" 
   SAY TIME()" - SUBMITTING HUTCNS COMMAND(S) FOR FOREGROUND PROCESSING" 
   PARSE VAR EXECHUTCNS Part1 '%%TDP_ID%%' Part2 
   "CALL "Part1""Logon.Logon_ID.Prefix""Part2 
   ERR_CODE = RC 
   SAY TIME()" - HUTCNS COMMAND(S) FOR FOREGROUND PROCESSING COMPLETED" 
   SAY " " 

   IF ERR_CODE = 0 THEN 
      DO 
      CALL LISTDSI(FILEID".HUTCNS") 
      IF SYSUSED > 0 THEN 
         ADDRESS ISPEXEC "BROWSE DATASET("FILEID".HUTCNS)" 
      ELSE 
         SAY CENTER("***** ANSWER SET IS EMPTY *****",80) 
      END 

   "ALLOC DDN(sysin) SHR DSN(*) REUSE" 
   CALL OUTTRAP "LINE.","0" 
   "FREE DDN(output, input)" 
   "DELETE "FILEID".SCRIPT" 
   "DELETE "FILEID".HUTCNS" 
   CALL OUTTRAP "OFF" 

   "DELSTACK" 
   RETURN 

/*--------------------- RUN BTEQ IN BACKGROUND ----------------------*/ 
RUNBACKGROUND: 
   JCLNAME = "BTEQJOB."MEMBR".CNTL" 
   IF LISTDSI(JCLNAME) <> 0 THEN 
      "ALLOC DDN(JCLFILE) NEW SPACE(1 1) TRACKS DSN("JCLNAME") REUSE" 
   ELSE 
      "ALLOC DDN(JCLFILE) SHR DSN("JCLNAME") REUSE" 

   "NEWSTACK" 
 /*QUEUE "//"USERID()""RIGHT(Logon.Logon_ID.Prefix,1)" JOB "JCLACCT",'"MEMBR"',"*/ 
   QUEUE "//"USERID()"R JOB "JCLACCT",'"MEMBR"'," 
   QUEUE "//             NOTIFY="USERID()"," 
   QUEUE "//             MSGCLASS="JCLMSGCLASS"," 
   QUEUE "//             MSGLEVEL="JCLMSGLEVEL"," 
   QUEUE "//             CLASS="JCLCLASS 
   QUEUE "//HUTCNS   EXEC PGM=HUTCNS" 
   StepWork = "//STEPLIB  DD DSN="JCLSTEP.1",DISP=SHR" 
   PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
   QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
   DO I = 2 TO JCLSTEP.0 
      StepWork = "//         DD DSN="JCLSTEP.I",DISP=SHR" 
      PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
      QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
      END 


   QUEUE "//SYSPRINT DD SYSOUT=*" 
   QUEUE "//OUTPUT   DD SYSOUT=*" 
   QUEUE "//SYSIN    DD *" 

   "ALLOC DDN(logon) SHR DSN("Logon.Logon_ID.Member") REUSE" 
   "EXECIO * DISKR logon (STEM Line. FINIS)" 
   "FREE  DDN(logon)" 
   PARSE UPPER VAR Line.1 . 'LOGON' Line.1 ';' . 
   QUEUE STRIP(Line.1, 'B') 

   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(XLINE) = LINE "I" " 
      QUEUE STRIP(XLINE, T) 
      END 
   QUEUE "END" 

   "EXECIO" QUEUED() "DISKW JCLFILE (FINIS)" 
   "FREE DDN(JCLFILE)" 
   "DELSTACK" 

   "SUBMIT "JCLNAME 

   CALL OUTTRAP "LINE.","0" 
   "DELETE "JCLNAME 
   CALL OUTTRAP "OFF" 

   RETURN 



/*--------------- LOAD BTEQ VARIABLES ---------------*/ 
LOADBTEQ: 
   CONFIG_NAME   = "'"USERID()".BTEQ.CONFIG'" 
   DO UNTIL PRE_EXIST 
      PRE_EXIST = (LISTDSI(CONFIG_NAME) = 0) 
      IF PRE_EXIST THEN DO 
         "ALLOC DDN(CONFIG) SHR DSN("CONFIG_NAME") REUSE" 
         "NEWSTACK" 
         "EXECIO * DISKR CONFIG (FINIS)" 
         DO QUEUED() 
            PARSE PULL CONFIG_PARAM 
            INTERPRET CONFIG_PARAM 
            END 
         "DELSTACK" 
         "FREE DDN(CONFIG)" 
         END 
      ELSE 
         CALL "BTEQINIT" CONFIG_NAME 
      END 
   RETURN 

CHOOSELOGON: 
   SAY "ENTER LOGON OPTION:" 
   DO I = 1 TO LOGON.0 
      SAY "    "I".  "LOGON.I.DESC 
      END 
   DO UNTIL (LOGON_ID > 0) & (LOGON_ID <= LOGON.0) 
      PARSE EXTERNAL LOGON_ID 
      END 
   RETURN LOGON_ID 

FINDLOGON: 
   PARSE UPPER ARG USERID 
   DO I = 1 TO LOGON.0 
      PARSE UPPER VAR LOGON.I.DESC XX 
      IF INDEX(XX, USERID) <> 0 THEN 
         RETURN I 
      END 
   RETURN 0 

CHOOSERUNOPTION: 
   SAY "ENTER RUN OPTION:" 
   SAY "    1.  RUN IN FOREGROUND" 
   SAY "    2.  RUN IN BACKGROUND" 
   SAY "    3.  BUILD BACKGROUND JOB AND EDIT" 
   DO UNTIL (RUN_OPTN > 0) & (RUN_OPTN <= 3) 
      PARSE EXTERNAL RUN_OPTN 
      END 
   RETURN RUN_OPTN 
