/*---------- REXX MACRO: BTEQ ---------------------------------------*/ 
/*                                                                   */ 
/*   This rexx macro will run the teradata bteq utility using the    */ 
/*      sql statement currently in the ispf editor buffer.  The      */ 
/*      output will be written to a temporary dataset and be browsed */ 
/*      when the query is complete.                                  */ 
/*                                                                   */ 
/*-------------------------------------------------------------------*/ 

ADDRESS ISREDIT "MACRO (PARM1)" 
ADDRESS ISREDIT "(FLINE) = LINENUM .ZFIRST" 
ADDRESS ISREDIT "(LLINE) = LINENUM .ZLAST" 
ADDRESS ISREDIT "(MEMBR) = MEMBER" 
CALL LOADBTEQ 

IF PARM1 = "" THEN DO 
   LOGON_ID = CHOOSELOGON() 
   RUN_OPTN = CHOOSERUNOPTION() 
   RUN_SESSION = "" 
   END 
ELSE DO 
   DO WHILE INDEX(PARM1, ',') <> 0 
      PARSE VAR PARM1 X1 ',' X2 
      PARM1 = X1" "X2 
      END 
   DO WHILE INDEX(PARM1, '.') <> 0 
      PARSE VAR PARM1 X1 '.' X2 
      PARM1 = X1" "X2 
      END 
   PARSE VAR PARM1 LOGON_ID RUN_OPTN RUN_SESSION . 
   END 

SELECT 
   WHEN RUN_OPTN = 1 THEN  CALL RUNFOREGROUND 
   WHEN RUN_OPTN = 2 THEN  CALL RUNBACKGROUND 
   WHEN RUN_OPTN = 3 THEN  CALL RUNBACKGROUND 
   WHEN RUN_OPTN = 4 THEN  CALL BUILDJOB 
   END 
RETURN 

/*--------------------- RUN BTEQ IN FOREGROUND ----------------------*/ 
RUNFOREGROUND: 
   "CLEAR" 
   SAY CENTER("GENERATE BTEQ COMMANDS",80) 
   SAY "" 

   "NEWSTACK" 
   FILEID = "BTEQ"RIGHT("0000"RANDOM(1,9999),4) 
   FATTR  = "NEW SPACE(10,10) TRACKS DIR(0) REUSE" 
   PARSE VAR JCLCTRANS Part1 '%%TDP_ID%%' Part2 
   "ALLOC DDN(CTRANS) SHR DSN('"Part1""Logon.Logon_ID.Prefix""Part2"') REUSE" 
   "ALLOC DDN(OUTDSN)   "FATTR" DSN("FILEID".QUERY)" 
   "ALLOC DDN(SYSIN)    "FATTR" DSN("FILEID".SCRIPT)" 
   "ALLOC DDN(SYSPRINT) "FATTR" DSN("FILEID".SYSPRINT)" 

   "ALLOC DDN(LOGON) SHR DSN("Logon.Logon_ID.Member") REUSE" 
   "EXECIO * DISKR LOGON (FINIS)" 
   "FREE  DDN(LOGON)" 
   QUEUE ".EXPORT REPORT DDNAME=OUTDSN,OPEN" 

   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(XLINE) = LINE "I" " 
      PARSE UPPER VAR XLINE TLINE 
      SELECT 
         WHEN ABBREV(TLINE, '.LOGON') <> 0  THEN NOP 
         WHEN ABBREV(TLINE, '.EXIT')  <> 0  THEN NOP 
         WHEN ABBREV(TLINE, '.QUIT')  <> 0  THEN NOP 
         WHEN ABBREV(TLINE, '.EXPORT') <> 0 THEN NOP 
         OTHERWISE   QUEUE STRIP(XLINE, 'T') 
         END 
      END 
   QUEUE ".EXIT ERRORCODE" 
   "EXECIO" QUEUED() "DISKW SYSIN (FINIS)" 

   SAY "" 
   SAY TIME()" - SUBMITTING SQL COMMAND(S) FOR FOREGROUND PROCESSING" 
   PARSE VAR EXECBTEQ Part1 '%%TDP_ID%%' Part2 
   "CALL "Part1""Logon.Logon_ID.Prefix""Part2 
   ERR_CODE = RC 
   SAY TIME()" - SQL COMMAND(S) FOR FOREGROUND PROCESSING COMPLETED" 
   "EXECIO * DISKR SYSPRINT (STEM RECD. FINIS)" 

   "FREE DDN(OUTDSN)" 
   "ALLOC DDN(SYSIN)    SHR DSN(*)   REUSE" 
   "ALLOC DDN(SYSPRINT) SHR DSN(*)   REUSE" 

   DO I = 1 TO RECD.0 
      PARSE UPPER VAR RECD.I TEMPSTR 
      SELECT 
         WHEN INDEX(TEMPSTR, '*** QUERY') <> 0 THEN 
            DO J = I TO I+1 
               SAY RECD.J 
               END 
         WHEN INDEX(TEMPSTR, '*** FAILURE') <> 0 THEN 
            DO J = I-2 TO I+2 
               SAY RECD.J 
               END 
         OTHERWISE   NOP 
         END 
      END 

   SAY " " 

   IF ERR_CODE = 0 THEN 
      DO 
      CALL LISTDSI(FILEID".QUERY") 
      IF SYSUSED > 0 THEN 
         ADDRESS ISPEXEC "BROWSE DATASET("FILEID".QUERY)" 
      ELSE 
         SAY CENTER("***** ANSWER SET IS EMPTY *****",80) 
      END 
   ELSE 
      ADDRESS ISPEXEC "BROWSE DATASET("FILEID".SYSPRINT)" 

   CALL OUTTRAP "LINE.","0" 
   "DELETE "FILEID".SYSPRINT" 
   "DELETE "FILEID".SCRIPT" 
   "DELETE "FILEID".QUERY" 
   CALL OUTTRAP "OFF" 

   "DELSTACK" 
   RETURN 

/*--------------------- RUN BTEQ IN BACKGROUND ----------------------*/ 
RUNBACKGROUND: 
   JCLNAME = "BTEQJOB."MEMBR".CNTL" 
   IF LISTDSI(JCLNAME) <> 0 THEN 
      "ALLOC DDN(JCLFILE) NEW SPACE(1 1) TRACKS DSN("JCLNAME") REUSE" 
   ELSE 
      "ALLOC DDN(JCLFILE) SHR DSN("JCLNAME") REUSE" 

   "NEWSTACK" 
   QUEUE "//"USERID()""RIGHT(Logon.Logon_ID.JobID,1)" JOB "JCLACCT",'"MEMBR"'," 
   QUEUE "//             NOTIFY="USERID()"," 
   QUEUE "//             MSGCLASS="JCLMSGCLASS"," 
   QUEUE "//             MSGLEVEL="JCLMSGLEVEL"," 
   QUEUE "//             CLASS="JCLCLASS 
   QUEUE "//BTEQ     EXEC PGM=BTQMAIN" 
   StepWork = "//STEPLIB  DD DSN="JCLSTEP.1",DISP=SHR" 
   PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
   QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
   DO I = 2 TO JCLSTEP.0 
      StepWork = "//         DD DSN="JCLSTEP.I",DISP=SHR" 
      PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
      QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
      END 

   /*----- BUILD DD STATEMENTS FOR EACH .EXPORT COMMAND -----*/ 
   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(XLINE) = LINE "I" " 
      PARSE UPPER VAR XLINE TLINE 
      IF ABBREV(STRIP(TLINE, 'B'), '.EXPORT') = 0 THEN 
         ITERATE 
      PARSE VAR TLINE . '=' DDN ',' . 
      DDN = LEFT(STRIP(DDN, 'B'), 8) 
      IF DDN = "" THEN 
         ITERATE 
      QUEUE "//"DDN" DD SYSOUT=*,LRECL=512,RECFM=VB,BLKSIZE=32000" 
      END 

   QUEUE "//SYSOUT   DD SYSOUT=*" 
   QUEUE "//SYSPRINT DD SYSOUT=*" 
   QUEUE "//SYSTERM  DD SYSOUT=*" 
   QUEUE "//SYSUDUMP DD SYSOUT=*" 
   PARSE VAR Logon.Logon_ID.Member "'" FileName "'" . 
   QUEUE "//SYSIN    DD DSN="FileName",DISP=SHR" 
   QUEUE "//         DD *" 

   IF RUN_SESSION <> '' THEN 
      QUEUE '.set sessions 'RUN_SESSION 

   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(XLINE) = LINE "I" " 
      QUEUE STRIP(XLINE, T) 
      END 
   QUEUE ".EXIT ERRORCODE" 

   "EXECIO" QUEUED() "DISKW JCLFILE (FINIS)" 
   "FREE DDN(JCLFILE)" 
   "DELSTACK" 

   SELECT 
      WHEN RUN_OPTN = 2 THEN 
         "SUBMIT "JCLNAME 
      WHEN RUN_OPTN = 3 THEN
         ADDRESS ISPEXEC "EDIT DATASET("JCLNAME")" 
      END 

   CALL OUTTRAP "LINE.","0" 
   "DELETE "JCLNAME 
   CALL OUTTRAP "OFF" 

   RETURN 


/*--------------- BUILD CATALOGED JOB ---------------*/ 
BUILDJOB: 
   JCLname = JOBLIBRARY"("MEMBR")" 
   "ALLOC DDN(jclfile) SHR DSN('"JCLname"') REUSE" 

   "NEWSTACK" 
   QUEUE "//"USERID()""RIGHT(Logon.Logon_ID.JobID,1)" JOB "JCLACCT",'"MEMBR"'," 
   QUEUE "//             NOTIFY="USERID()"," 
   QUEUE "//             MSGCLASS="JCLMSGCLASS"," 
   QUEUE "//             MSGLEVEL="JCLMSGLEVEL"," 
   QUEUE "//             CLASS="JCLCLASS 
   QUEUE "//BTEQ     EXEC PGM=BTQMAIN" 
   StepWork = "//STEPLIB  DD DSN="JCLSTEP.1",DISP=SHR" 
   PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
   QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
   DO I = 2 TO JCLSTEP.0 
      StepWork = "//         DD DSN="JCLSTEP.I",DISP=SHR" 
      PARSE VAR StepWork Part1 '%%TDP_ID%%' Part2 
      QUEUE Part1""Logon.Logon_ID.Prefix""Part2 
      END 

   /*----- BUILD DD STATEMENTS FOR EACH .EXPORT COMMAND -----*/ 
   DO I = FLINE TO LLINE 
      ADDRESS ISREDIT "(XLINE) = LINE "I" " 
      PARSE UPPER VAR XLINE TLINE 
      IF ABBREV(STRIP(TLINE, 'B'), '.EXPORT') = 0 THEN 
         ITERATE 
      PARSE VAR TLINE . '=' DDN ',' . 
      DDN = LEFT(STRIP(DDN, 'B'), 8) 
      IF DDN = "" THEN 
         ITERATE 
      QUEUE "//"DDN" DD SYSOUT=*,LRECL=512,RECFM=VB,BLKSIZE=32000" 
      END 

   QUEUE "//SYSOUT   DD SYSOUT=*" 
   QUEUE "//SYSPRINT DD SYSOUT=*" 
   QUEUE "//SYSTERM  DD SYSOUT=*" 
   QUEUE "//SYSUDUMP DD SYSOUT=*" 
   ADDRESS ISREDIT "(dsn) = DATASET" 
   PARSE VAR LOGON.LOGON_ID.MEMBER "'" LogonName "'" . 
   QUEUE "//SYSIN    DD DSN="LogonName",DISP=SHR" 
   QUEUE "//         DD DSN="dsn"("MEMBR"),DISP=SHR" 
   PARSE VAR LogonName Part1 '(' . ')' Part2 
   QUEUE "//         DD DSN="Part1"("QUIT")"Part2",DISP=SHR" 
   QUEUE "//" 

   "EXECIO" QUEUED() "DISKW jclfile (FINIS)" 
   "FREE DDN(jclfile)" 

   "DELSTACK" 
   ADDRESS ISPEXEC "EDIT DATASET('"JCLNAME"')" 
   RETURN 


/*--------------- LOAD BTEQ VARIABLES ---------------*/ 
LOADBTEQ: 
   CONFIG_NAME   = "'"USERID()".BTEQ.CONFIG'" 
   DO UNTIL PRE_EXIST 
      PRE_EXIST = (LISTDSI(CONFIG_NAME) = 0) 
      IF PRE_EXIST THEN DO 
         "ALLOC DDN(CONFIG) SHR DSN("CONFIG_NAME") REUSE" 
         "NEWSTACK" 
         "EXECIO * DISKR CONFIG (FINIS)" 
         DO QUEUED() 
            PARSE PULL CONFIG_PARAM 
            INTERPRET CONFIG_PARAM 
            END 
         "DELSTACK" 
         "FREE DDN(CONFIG)" 
         END 
      ELSE 
         CALL "BTEQINIT" CONFIG_NAME 
      END 
   RETURN 

CHOOSELOGON: 
   SAY "ENTER LOGON OPTION:" 
   DO I = 1 TO LOGON.0 
      SAY "    "I".  "LOGON.I.DESC 
      END 
   DO UNTIL (LOGON_ID > 0) & (LOGON_ID <= LOGON.0) 
      PARSE EXTERNAL LOGON_ID 
      END 
   RETURN LOGON_ID 

FINDLOGON: 
   PARSE UPPER ARG USERID 
   DO I = 1 TO LOGON.0 
      PARSE UPPER VAR LOGON.I.DESC XX 
      IF INDEX(XX, USERID) <> 0 THEN 
         RETURN I 
      END 
   RETURN 0 

CHOOSERUNOPTION: 
   SAY "ENTER RUN OPTION:" 
   SAY "    1.  RUN IN FOREGROUND" 
   SAY "    2.  RUN IN BACKGROUND" 
   SAY "    3.  BUILD BACKGROUND JOB AND EDIT" 
   DO UNTIL (RUN_OPTN > 0) & (RUN_OPTN <= 3) 
      PARSE EXTERNAL RUN_OPTN 
      END 
   RETURN RUN_OPTN 
