/*--- REXX ----------------------------------------- TECH TIP 119 ----*/ 
/* SYNTAX:   REPORTS  rpt  sdate edate stime etime                    */ 
/*------------------------------------------------------ Tools -------*/ 
/* rpt => Is a string of chars, one char for each report              */ 
/*                                                                    */ 
/*  A=ARC/HUT Info *      B=AmpUsage              C=User Info         */ 
/*  D=Get DDL             E=Errorlog Reports      F=FB/JRNL Info      */ 
/*  G=Tbl/Col Info        H=                      I=                  */ 
/*  J=USI/NUSI Info       K=                      L=LogonOff Rpts *   */ 
/*  M=                    N=Help Database         O=                  */ 
/*  P=Space Reports       Q=                      R=ResUsage Rpts *   */ 
/*  S=SessionInfo         T=Heirarchy Tree        U=Rights for User   */ 
/*  V=Rights on DB        W=Day-Of-Week           X=Transport DDL     */ 
/*  Y=                    Z=REPORTS EXEC Setup    1=HUTCNS CON        */ 
/*  2=HUTCNS LOC          3=HUTCNS SES            4=HUTCNS RCV        */ 
/*                                                                    */ 
/*  (*) Options: sdate   edate    Default:  current date (or *)       */ 
/*               stime   etime    Default:  0 - 240000   (or *)       */ 
/*--------------------------------------------------------------------*/ 
TRACE N 
ADDRESS TSO 

ARG args 
PARSE UPPER VAR args rpt sdate edate stime etime logon_id . 
CALL LoadBTEQ 

DO FOREVER 
   IF rpt = '' THEN 
      CALL DOHELP2 
   ELSE 
      LEAVE 
   END 

IF INDEX(rpt, 'X') > 0 THEN 
   DO 
   IF rpt <> 'X' THEN 
      DO 
      SAY "" 
      SAY"Option 'X' must be run standalone" 
      SAY "" 
      EXIT 
      END 
   END 

CALL GETDATE 

fileid = "BTEQ"RANDOM(1,9999) 

/*--------------------------------------------------------------------*/ 
/*               M A I N        S E C T I O N                         */ 
/*--------------------------------------------------------------------*/ 

/*--------------------------------------------------------------------*/ 
/*  Verify and setup parameter list options.                          */ 
/*--------------------------------------------------------------------*/ 

SELECT 
   WHEN INDEX(rpt,'A') > 0  THEN NOP 
   WHEN INDEX(rpt,'B') > 0  THEN NOP 
   WHEN INDEX(rpt,'C') > 0  THEN NOP 
   WHEN INDEX(rpt,'D') > 0  THEN NOP 
   WHEN INDEX(rpt,'E') > 0  THEN NOP 
   WHEN INDEX(rpt,'F') > 0  THEN NOP 
   WHEN INDEX(rpt,'G') > 0  THEN NOP 
   WHEN INDEX(rpt,'J') > 0  THEN NOP 
   WHEN INDEX(rpt,'L') > 0  THEN NOP 
   WHEN INDEX(rpt,'N') > 0  THEN NOP 
   WHEN INDEX(rpt,'P') > 0  THEN NOP 
   WHEN INDEX(rpt,'R') > 0  THEN NOP 
   WHEN INDEX(rpt,'S') > 0  THEN NOP 
   WHEN INDEX(rpt,'T') > 0  THEN NOP 
   WHEN INDEX(rpt,'U') > 0  THEN NOP 
   WHEN INDEX(rpt,'V') > 0  THEN NOP 
   WHEN INDEX(rpt,'W') > 0  THEN NOP 
   WHEN INDEX(rpt,'X') > 0  THEN NOP 
   WHEN INDEX(rpt,'Z') > 0  THEN NOP 
   WHEN INDEX(rpt,'1') > 0  THEN NOP 
   WHEN INDEX(rpt,'2') > 0  THEN NOP 
   WHEN INDEX(rpt,'3') > 0  THEN NOP 
   WHEN INDEX(rpt,'4') > 0  THEN NOP 
   OTHERWISE CALL dohelp 
   END 

"CLEAR" 
/*--------CUSTOMER_X Modification--------*/ 
   logon_id = "1" 
/*----------------------------------*/ 
IF logon_id = "" THEN 
   logon_id = ChooseLogon() 
logonstring = logon.logon_id.string 

resdbdef = "DBC" 
feets = ".set footing 'USER ("USERID()") Requested Report'" 

SELECT 
   WHEN DATATYPE(sdate) = 'NUM'  THEN NOP 
   WHEN sdate           = '*'    THEN sdate = dater 
   WHEN sdate           = ''     THEN 
      DO 
      sdate = dater 
      edate = dater 
      stime = 000000 
      etime = 240000 
      END 
   OTHERWISE 
      CALL dohelp 
   END 
sdatex = editit(sdate,"/") 

SELECT 
   WHEN DATATYPE(edate) = 'NUM'  THEN NOP 
   WHEN edate           = '*'    THEN edate = dater 
   WHEN edate           = ''     THEN 
      DO 
      edate = dater 
      stime = 000000 
      etime = 240000 
      END 
   OTHERWISE 
      CALL dohelp 
   END 
edatex = editit(edate,"/") 

SELECT 
   WHEN DATATYPE(stime) = 'NUM'  THEN NOP 
   WHEN stime           = '*'    THEN stime = 0 
   WHEN stime           = ''     THEN 
      DO 
      stime = 000000 
      etime = 240000 
      END 
   OTHERWISE 
      CALL dohelp 
   END 
stimex = editit(stime,":") 

SELECT 
   WHEN DATATYPE(etime) = 'NUM'  THEN NOP 
   WHEN etime           = '*'    THEN etime = 240000 
   WHEN etime           = ''     THEN etime = 240000 
   OTHERWISE 
      CALL dohelp 
   END 
etimex = editit(etime,":") 

/*--------------------------------------------------------------------*/ 
/*  Do pre-setup work for options C, D, F, G, H, J, K, M, R,          */ 
/*  T, U, V prior to creating report SQL.                             */ 
/*--------------------------------------------------------------------*/ 

errstring = 0 
if INDEX(rpt, 'C') > 0 THEN  CALL doacct1 
if INDEX(rpt, 'D') > 0 THEN  CALL doddl1 
if INDEX(rpt, 'E') > 0 THEN  CALL doerr1 
if INDEX(rpt, 'F') > 0 THEN  CALL dofb1 
if INDEX(rpt, 'G') > 0 THEN  CALL dotc1 
if INDEX(rpt, 'J') > 0 THEN  CALL doindx1 
if INDEX(rpt, 'L') > 0 THEN  CALL dolgn1 
if INDEX(rpt, 'N') > 0 THEN  CALL dodbhelp1 
if INDEX(rpt, 'R') > 0 THEN  CALL dores1 
if INDEX(rpt, 'T') > 0 THEN  CALL dotree1 
if INDEX(rpt, 'U') > 0 THEN  CALL dousr1 
if INDEX(rpt, 'V') > 0 THEN  CALL dov1 
if INDEX(rpt, 'W') > 0 THEN  CALL dod2w1 
if INDEX(rpt, 'X') > 0 THEN  CALL dotrans1 
if INDEX(rpt, 'P') > 0 THEN  CALL dospc 

"NEWSTACK" 
dtl2 = 0 
dtl3 = 0 
/*----- QUEUE logonstring -----*/ 

IF INDEX(rpt,'A') > 0        THEN CALL doarc     ELSE arc     = 0 
IF INDEX(rpt,'B') > 0        THEN CALL doamu     ELSE amu     = 0 
IF INDEX(rpt,'C') > 0        THEN CALL doacct2   ELSE act     = 0 
IF INDEX(rpt,'F') > 0        THEN CALL dofb2     ELSE fb      = 0 
IF INDEX(rpt,'G') > 0        THEN CALL dotc2     ELSE tc      = 0 
IF INDEX(rpt,'J') > 0        THEN CALL doindx2   ELSE indx    = 0 
IF INDEX(rpt,'L') > 0        THEN CALL dolgn2    ELSE lgn     = 0 
IF INDEX(rpt,'N') > 0        THEN CALL dodbhelp2 ELSE dhp     = 0 
IF INDEX(rpt,'R') > 0        THEN CALL dores2    ELSE res     = 0 
IF INDEX(rpt,'S') > 0        THEN CALL doses     ELSE ses     = 0 
IF INDEX(rpt,'T') > 0        THEN CALL dotree2   ELSE tre     = 0 
IF INDEX(rpt,'U') > 0        THEN CALL dousr2    ELSE rgt     = 0 
IF INDEX(rpt,'V') > 0        THEN CALL dov2      ELSE rgtv    = 0 
IF INDEX(rpt,'W') > 0        THEN CALL dod2w2    ELSE d2w     = 0 
IF INDEX(rpt,'X') > 0        THEN CALL dotrans2  ELSE trans   = 0 
IF INDEX(errstring,'A') > 0  THEN CALL doerr2    ELSE err     = 0 
IF INDEX(errstring,'B') > 0  THEN CALL doevl2    ELSE evtf    = 0 
IF INDEX(errstring,'C') > 0  THEN CALL dox       ELSE dox     = 0 
IF spcprm  = 1               THEN CALL doprm     ELSE prm     = 0 
IF spcspl  = 1               THEN CALL docspool2 ELSE cspl    = 0 
IF spcpctd = 1               THEN CALL dodtl2 
IF spcpcts = 1               THEN CALL dopct2    ELSE pct     = 0 
IF spcpctt = 1               THEN CALL dodtl3 
IF spcprms = 1               THEN CALL dosum2    ELSE prmsum  = 0 
IF spcsplx = 1               THEN CALL dosplx 
/* This is always run last because */ 
/* it involves the SYSPRINT file   */ 
IF INDEX(rpt,'D') > 0        THEN CALL doddl2    ELSE ddlflag = 0 

SELECT 
   WHEN INDEX(rpt,'1') > 0  THEN hutin = 1 
   WHEN INDEX(rpt,'2') > 0  THEN hutin = 1 
   WHEN INDEX(rpt,'3') > 0  THEN hutin = 1 
   WHEN INDEX(rpt,'4') > 0  THEN hutin = 1 
   OTHERWISE                     hutin = 0 
   END 

QUEUE "" 
logoffstring = ".exit errorcode" 
workid = fileid".QUERY" 
"ALLOC DDN(worklib) NEW SPACE(20,20) DIR(5) TRACKS LRECL(133)", 
      "DSN("workid")" 
"FREE  DDN(worklib)" 
QUEUE logoffstring 
"ALLOC DDN(script) DSN("workid"(bteqsql))" 
"EXECIO "QUEUED()" DISKW script (FINIS)" 
"FREE DDN(script)" 
k = 0 
CALL domain 

/*-------------------------------------------------------*/ 
/* The following logic can be used to keep file hanging  */ 
/* around after execution for debugging purposes.        */ 
/*-------------------------------------------------------*/ 

"CLEAR" 
SAY "Your SQL has been generated. " 
/*----------CUSTOMER_X Modification------------------------*/ 
/* SAY "Enter a blank line if you want to run them."  */ 
/* SAY "Else enter QUIT."                             */ 
/* PARSE UPPER EXTERNAL answr                         */ 
answr = '' 
/*----------------------------------------------------*/ 
IF answr = '' THEN 
   DO 
   SAY "" 
   SAY "Generating your reports . . ." 
   SAY "" 
   IF k > 0 THEN              /* Bypass if no Reports Requested */ 
      ADDRESS ISPEXEC "EDIT DATASET("workid"(bteqsql))" 
   END 
ELSE 
   DO 
   SAY fileid".EXEC will not be executed. You may run it manually." 
   SAY "(HUTCNS and DDL options will not be run)" 
   SAY "" 
   EXIT 
   END 

IF hutin = 1 THEN 
   CALL dohut 

"FREE DDN("outexec")" 
CALL OUTTRAP "line.","0" 
"DELETE "fileid".EXEC" 
"DELETE "workid"" 
CALL OUTTRAP "OFF" 

/*----------------CUSTOMER_X Modification----------------------*/ 
/*  SAY ""                                                */ 
/*  SAY "Do you want to keep the output datasets? (Y/N)"  */ 
/*  DO FOREVER                                            */ 
/*     PARSE UPPER EXTERNAL keepdata                      */ 
/*     SELECT                                             */ 
/*        WHEN LEFT(keepdata, 1) = "Y"  THEN LEAVE        */ 
/*        WHEN LEFT(keepdata, 1) = "N"  THEN LEAVE        */ 
/*        OTHERWISE   NOP                                 */ 
/*        END                                             */ 
/*     END                                                */ 
keepdata = "N" 
/*--------------------------------------------------------*/ 

IF LEFT(keepdata, 1) = "N" THEN 
   DO 
   CALL OUTTRAP "line","0" 
   "DELETE "workid"" 
   CALL OUTTRAP "OFF" 
   END 
ELSE 
   SAY "Query Output stored in Dataset '"USERID()"."workid" PDS." 
"CLEAR" 

"DELSTACK" 
/*---------------------------------------*/ 
                /*                       */ 
EXIT            /*  End of MAIN SECTION  */ 
                /*                       */ 
/*---------------------------------------*/ 

/*--------------------------------------------------------------------*/ 
/*  DOMAIN  - Queue BTEQ exec for MVS execution                       */ 
/*--------------------------------------------------------------------*/ 
DOMAIN: 
   k = 0 

   QUEUE "/*-----REXX EXEC for DBC Status Reporting-----*/" 
   QUEUE '"ALLOC DDN(CTRANS) SHR REUSE DSN('''jclLibrary''')"' 
   QUEUE '"ALLOC DDN(SYSIN) SHR REUSE DSN('workid'(BTEQSQL))"' 
   QUEUE '"ALLOC DDN(SYSOUT)   DUMMY  REUSE"' 
   QUEUE '"ALLOC DDN(SYSPRINT) DUMMY  REUSE"' 
   IF arc    = 1 THEN  CALL filedef 'rptarc','Archive Report' 
   IF prmsum = 1 THEN  CALL filedef 'rptsum','DB/Table Perm Summary' 
   IF spcsplx= 1 THEN  CALL filedef 'rptsplx','Max Spool Report' 
   IF tc     = 1 THEN  CALL filedef 'rpttc','Table-Column Report' 
   IF err    = 1 THEN  CALL filedef 'rpterr','ErrorLog Report' 
   IF amu    = 1 THEN  CALL filedef 'rptamu','AmpUsage Report' 
   IF d2w    = 1 THEN  CALL filedef 'rptd2w','Day-of-Week' 
   IF cspl   = 1 THEN  CALL filedef 'rptspl','Spool Space Report' 
   IF lgn    = 1 THEN  CALL filedef 'rptlgn','LogonOff Report' 
   IF res    = 1 THEN  CALL filedef 'rptres','ResUsage Report' 
   IF evtf   = 1 THEN  CALL filedef 'rptevl','ErrorLog by Event Report' 
   IF ses    = 1 THEN  CALL filedef 'rptses','Session Info Report' 
   IF rgt    = 1 THEN  CALL filedef 'rptrgt','Rights for a User Report' 
   IF rgtv   = 1 THEN  CALL filedef 'rptdrgt','Rights on a DB Report' 
   IF act    = 1 THEN  CALL filedef 'rptacct','User Profile Report' 
   IF dhp    = 1 THEN  CALL filedef 'dhprpt','Help Database Report' 
   IF dox    = 1 THEN  CALL filedef 'rptdox','Serious Events Report' 
   IF prm    = 1 THEN  CALL filedef 'rptprm','PermSpace Report' 
   IF tre    = 1 THEN  CALL filedef 'rpttre','Ownership Report' 
   IF pct    = 1 THEN  CALL filedef 'rptpct','Perm Skew Report' 
   IF dtl2   = 1 THEN  CALL filedef 'rptdlt2','DB Perm by AMP Report' 
   IF dtl3 = 1 THEN  CALL filedef 'rptdtl3','Table Perm by AMP Report'  ) 
   IF trans  = 1 THEN  CALL filedef 'runshows','DDL Transported' 
   IF fb     = 1 THEN  CALL filedef 'prtfb','Fallback Tables Report' 
   IF indx   = 1 THEN  CALL filedef 'rptindx','Table Indexes Report' 
   IF ddl    = 1 THEN  CALL filedef 'rptddl','DDL for DB Entities' 
   QUEUE '"CALL 'execBTEQ'"' 
   IF trans = 1 THEN 
      DO 
      QUEUE '/*----- This is for Transporting DDL -----*/' 
      QUEUE '"ALLOC DDN(sysin) SHR REUSE DSN('workid'(RUNSHOWS))"' 
      QUEUE '"CALL 'execBTEQ'"' 
      QUEUE ' ' 
      QUEUE '"DELETE 'workid'(BTEQSQL)"' 
      QUEUE '"DELETE 'fileid'.EXEC"' 
      END 
   IF ddlflag = 1 THEN      /* Copy SYSPRINT file for EDITing */ 
      QUEUE '"COPY 'workid'(SYSPRINT) 'workid'(RPTDDL)"' 
   QUEUE " " 
   "ALLOC DDN(outexec) NEW SPACE(1,1) TRACKS REUSE DSN("fileid".EXEC)" 
   "EXECIO" QUEUED() "DISKW outexec (FINIS)" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOHUT - See if HUTCNS request are present and execute them        */ 
/*--------------------------------------------------------------------*/ 
DOHUT: 
   hutparams = "'NOSPIE'" 
   IF INDEX(rpt,'1') > 0 THEN 
      DO 
      CALL filedef 'hutcon','HUTCNS Config Report','output' 
      QUEUE '"ALLOC DDN(SYSOUT) DUMMY REUSE"' 
      QUEUE '"ALLOC DDN(INPUT) DSN('workid'(HUTSQL))"' 
      QUEUE '"CALL 'execHUTCNS' 'hutparams'"' 
      QUEUE '"FREE DDN(sysout, input, output)"' 
      QUEUE '"DELETE 'workid'(HUTSQL))"' 
      "EXECIO "QUEUED()" DISKW OUTEXEC (FINIS)" 
      QUEUE logonstring 
      QUEUE "con" 
      QUEUE "all" 
      QUEUE "end" 
      QUEUE "" 
      "ALLOC DDN(OUTCMDS) DSN("workid"(HUTSQL))" 
      "EXECIO "QUEUED()" DISKW OUTCMDS (FINIS)" 
      "FREE DDN(OUTCMDS)" 
      "EXEC "fileid" EXEC" 
      hutcns = RC 
      CALL OUTTRAP "line.","0" 
      "DELETE "workid"(HUTSQL)" 
      IF hutcns <> 0 THEN 
         DO 
         SAY "HUTCNS CON failed with RC = "hutcns 
         RETURN 
         END 
      END 
   IF INDEX(rpt,'2') > 0 THEN 
      DO 
      CALL filedef 'hutlock','HUTCNS Lock Report','output' 
      QUEUE '"ALLOC DDN(INPUT) SHR REUSE' 
      QUEUE '       DDN('fileid'.HUTCON.INPT)"' 
      QUEUE '"CALL 'execHUTCNS' 'hutparams'"' 
      QUEUE '"FREE DDN(sysout, input, output)"' 
      QUEUE '"CALL OUTTRAP "line.","0"' 
      QUEUE '"DELETE 'workid'.HUTCON.SYSOUT)"' 
      QUEUE '"DELETE 'workid'.HUTCON.INPT)"' 
      "EXECIO "QUEUED()" DISKW OUTEXEC (FINIS)" 
      QUEUE logonstring 
      QUEUE "loc" 
      QUEUE "end" 
      QUEUE "" 
      "ALLOC DDN(OUTCMDS) NEW SPACE(1,1) TRACKS", 
            "DSN("fileid".HUTCON.INPT)" 
      "EXECIO "QUEUED()" DISKW OUTCMDS (FINIS)" 
      "FREE DDN(OUTCMDS)" 
      "EXEC "fileid" EXEC" 
      hutcns = RC 
      CALL OUTTRAP "line.","0" 
      "DELETE "fileid".HUTCON.INPT" 
      "DELETE "fileid".HUTCON.EXEC" 
      IF hutcns <> 0 THEN 
         DO 
         SAY "HUTCNS CON failed with RC = "hutcns 
         RETURN 
         END 
      END 
   IF INDEX(rpt,'3') > 0 THEN 
      DO 
      CALL filedef 'hutses','HUTCNS Session Report','output' 
      QUEUE '"ALLOC DDN(SYSOUT) NEW SPACE(10, 10) TRACKS REUSE' 
      QUEUE '       DDN('fileid'.HUTCON.SYSOUT)"' 
      QUEUE '"ALLOC DDN(INPUT) SHR REUSE' 
      QUEUE '       DDN('fileid'.HUTCON.INPT)"' 
      QUEUE '"CALL 'execHUTCNS' 'hutparams'"' 
      QUEUE '"FREE DDN(sysout, input, output)"' 
      QUEUE '"CALL OUTTRAP "line.","0"' 
      QUEUE '"DELETE 'fileid'.HUTCON.SYSOUT)"' 
      QUEUE '"DELETE 'fileid'.HUTCON.INPT)"' 
      "ALLOC DDN(OUTEXEC) NEW SPACE(1,1) TRACKS", 
            "DSN("fileid".HUTCON.EXEC)" 
      "EXECIO "QUEUED()" DISKW OUTEXEC (FINIS)" 
      "FREE DDN(OUTEXEC)" 
      QUEUE logonstring 
      QUEUE "ses" 
      QUEUE "*" 
      QUEUE "*" 
      QUEUE "y" 
      QUEUE "" 
      QUEUE "end" 
      QUEUE "end" 
      QUEUE "" 
      "ALLOC DDN(OUTCMDS) NEW SPACE(1,1) TRACKS", 
            "DSN("fileid".HUTCON.INPT)" 
      "EXECIO "QUEUED()" DISKW OUTCMDS (FINIS)" 
      "FREE DDN(OUTCMDS)" 
      "EXEC "fileid".HUTCON.EXEC EXEC" 
      hutcns = RC 
      CALL OUTTRAP "line.","0" 
      "DELETE "fileid".HUTCON.INPT" 
      "DELETE "fileid".HUTCON.EXEC" 
      IF hutcns <> 0 THEN 
         DO 
         SAY "HUTCNS CON failed with RC = "hutcns 
         RETURN 
         END 
      END 
   IF INDEX(rpt,'4') > 0 THEN 
      DO 
      CALL filedef 'hutcon','HUTCNS Recovery Report','output' 
      QUEUE '"ALLOC DDN(SYSOUT) NEW DELETE SPACE(10, 10) TRACKS REUSE' 
      QUEUE '       DDN('fileid'.HUTCON.SYSOUT)"' 
      QUEUE '"ALLOC DDN(INPUT) SHR REUSE' 
      QUEUE '       DDN('fileid'.HUTCON.INPT)"' 
      QUEUE '"CALL 'execHUTCNS' 'hutparams'"' 
      QUEUE '"FREE DDN(sysout, input, output)"' 
      QUEUE '"CALL OUTTRAP "line.","0"' 
      QUEUE '"DELETE 'fileid'.HUTCON.INPT)"' 
      "ALLOC DDN(OUTEXEC) NEW SPACE(1,1) TRACKS", 
            "DSN("fileid".HUTCON.EXEC)" 
      "EXECIO "QUEUED()" DISKW OUTEXEC (FINIS)" 
      "FREE DDN(OUTEXEC)" 
      QUEUE logonstring 
      QUEUE "rcv" 
      QUEUE "list status;" 
      QUEUE "list locks;" 
      QUEUE "quit;" 
      QUEUE "end" 
      QUEUE "" 
      "ALLOC DDN(OUTCMDS) NEW SPACE(1,1) TRACKS", 
            "DSN("fileid".HUTCON.INPT)" 
      "EXECIO "QUEUED()" DISKW OUTCMDS (FINIS)" 
      "FREE DDN(OUTCMDS)" 
      "EXEC "fileid".HUTCON.EXEC EXEC" 
      hutcns = RC 
      CALL OUTTRAP "line.","0" 
      "DELETE "fileid".HUTCON.INPT" 
      "DELETE "fileid".HUTCON.EXEC" 
      IF hutcns <> 0 THEN 
         DO 
         SAY "HUTCNS CON failed with RC = "hutcns 
         RETURN 
         END 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  FILEDEF(fname,fdesc,ddname) - ALLOC statement and track file      */ 
/*--------------------------------------------------------------------*/ 
FILEDEF: 
   PARSE ARG fname, fdesc, ddname 
   k = k + 1 
   fdesc = fdesc"                             " 
   UPPER fname 
   IF ddname = '' THEN 
      ddname = fname 
   UPPER ddname 
   xt.k = fname 
   dt.k = LEFT(fdesc, 25) 
   QUEUE '"ALLOC DDN('ddname') REUSE DSN('workid'('xt.k'))"' 
   RETURN k 

/*--------------------------------------------------------------------*/ 
/*--------------------- PRE-SETUP  ROUTINES --------------------------*/ 
/*--------------------------------------------------------------------*/ 

/*--------------------------------------------------------------------*/ 
/*  DOTC1 - Get Table Column Specifics                                */ 
/*--------------------------------------------------------------------*/ 
DOTC1: 
   tc = 1 
   DO FOREVER 
      "CLEAR" 
      SAY "You have requested column info be reported" 
      SAY "for all tables in a database. Enter a database" 
      SAY "name now:" 
      PARSE UPPER EXTERNAL tcans 
      IF tcans = "QUIT"  THEN EXIT 
      IF tcans <> ""     THEN LEAVE 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOLGN1 - Get LogonOff specifics                                   */ 
/*--------------------------------------------------------------------*/ 
DOLGN1: 
   lgn = 1 
   DO FOREVER 
      "CLEAR" 
      SAY "You have requested logonoff info to be reported." 
      SAY "Enter a string of characters, one character for" 
      SAY "each report you would like:" 
      SAY "" 
      SAY "Uses initial dates and times entered as options:" 
      SAY "        1)  Active Users during time period" 
      SAY "        2)  Logonoff detail" 
      SAY "Uses initial dates, and prompts for time ranges:" 
      SAY "        3)  Logons      USER by HOUR" 
      SAY "        4)  Logons      IFP  by HOUR" 
      SAY "        5)  Logons      HOST by HOUR" 
      SAY "        6)  Logons      USER/HOST by HOUR" 
      PARSE UPPER EXTERNAL lgnopt 
      IF lgnopt = "QUIT" THEN EXIT 
      SELECT 
         WHEN INDEX(lgnopt,'1') > 0  THEN LEAVE 
         WHEN INDEX(lgnopt,'2') > 0  THEN LEAVE 
         WHEN INDEX(lgnopt,'3') > 0  THEN LEAVE 
         WHEN INDEX(lgnopt,'4') > 0  THEN LEAVE 
         WHEN INDEX(lgnopt,'5') > 0  THEN LEAVE 
         WHEN INDEX(lgnopt,'6') > 0  THEN LEAVE 
         OTHERWISE  NOP 
         END 
      END 
   lgnoptpd = 0 
   IF lgnopt > 2 THEN 
      DO FOREVER 
         SAY "You have requested logonoff info to be reported" 
         SAY "by hour. Enter one (1) of the reporting periods" 
         SAY "by number: (Initial time entries are ignored.)" 
         SAY "" 
         SAY "            1)  12am -  6am" 
         SAY "            2)   6am - 12pm" 
         SAY "            3)  12pm -  6pm" 
         SAY "            4)   6pm - 12am" 
         PARSE UPPER EXTERNAL lgnoptpd 
         IF lgnoptpd = "QUIT"  THEN EXIT 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
              DO 
              t11 = 000000; t21 = 005959 
              t12 = 010000; t22 = 015959 
              t13 = 020000; t23 = 025959 
              t14 = 030000; t24 = 035959 
              t15 = 040000; t25 = 045959 
              t16 = 050000; t26 = 055959 
              LEAVE 
              END 
            WHEN lgnoptpd = 2 THEN 
              DO 
              t11 = 060000; t21 = 065959 
              t12 = 070000; t22 = 075959 
              t13 = 080000; t23 = 085959 
              t14 = 090000; t24 = 095959 
              t15 = 100000; t25 = 105959 
              t16 = 110000; t26 = 115959 
              LEAVE 
              END 
            WHEN lgnoptpd = 3 THEN 
              DO 
              t11 = 120000; t21 = 125959 
              t12 = 130000; t22 = 135959 
              t13 = 140000; t23 = 145959 
              t14 = 150000; t24 = 155959 
              t15 = 160000; t25 = 165959 
              t16 = 170000; t26 = 175959 
              LEAVE 
              END 
            WHEN lgnoptpd = 4 THEN 
              DO 
              t11 = 180000; t21 = 185959 
              t12 = 190000; t22 = 195959 
              t13 = 200000; t23 = 205959 
              t14 = 210000; t24 = 215959 
              t15 = 220000; t25 = 225959 
              t16 = 230000; t26 = 235959 
              LEAVE 
              END 
           OTHERWISE NOP 
           END 
        END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOTRANS1 - Get DDL transfer SQL Specs                             */ 
/*--------------------------------------------------------------------*/ 
DOTRANS1: 
   transtdp = logonstring 
   trans = 1 
   DO FOREVER 
      "CLEAR" 
      SAY "**  OPTION  X  -  (DDL Transfer)  **" 
      SAY " " 
      SAY "You have requested a transfer of DDL.  Enter the" 
      SAY "number which describes your transfer request:" 
      SAY "" 
      SAY "Database-to-Database:" 
      SAY "        1)  within same DBC" 
/*    SAY "        2)  different DBCs" */ 
      PARSE UPPER EXTERNAL transdescr 
      IF Transdescr = "QUIT"  THEN EXIT 
      SELECT 
         WHEN INDEX(transdescr,"1") > 0  THEN LEAVE 
/*       WHEN INDEX(transdescr,"2") > 0  THEN LEAVE */ 
         OTHERWISE  NOP 
         END 
      END 
   SAY "" 
   SAY "Enter the SOURCE (FROM) databasename:" 
   PARSE UPPER EXTERNAL transsource 
   IF transsource = "QUIT"  THEN EXIT 
   DO FOREVER 
      "CLEAR" 
      SAY "**  OPTION  X  -  (DDL Transfer)  **" 
      SAY "" 
      SAY "To transfer DDL from" transsource 
      SAY "Enter ONE (1) of the following:" 
      SAY "       't' to transfer ALL table DDL" 
      SAY "       'v' to transfer ALL view  DDL" 
      SAY "       'm' to transfer ALL macro DDL" 
      SAY "       't1' to transfer a specific table's DDL" 
      SAY "       'v1' to transfer a specific view's  DDL" 
      SAY "       'm1' to transfer a specific macro's DDL" 
      PARSE UPPER EXTERNAL transkind 
      SELECT 
         WHEN transkind = "QUIT"  THEN EXIT 
         WHEN transkind = "T1" THEN 
            DO 
            CALL findddlname 
            LEAVE 
            END 
         WHEN transkind = "V1" THEN 
            DO 
            CALL findddlname 
            LEAVE 
            END 
         WHEN transkind = "M1" THEN 
            DO 
            CALL findddlname 
            LEAVE 
            END 
         WHEN transkind = "T"  THEN LEAVE 
         WHEN transkind = "V"  THEN LEAVE 
         WHEN transkind = "M"  THEN LEAVE 
         OTHERWISE  NOP 
         END 
      END 
   IF transdescr = 2 THEN 
      DO 
      "CLEAR" 
      SAY "**  OPTION  X  -  (DDL Transfer)  **" 
      SAY "" 
      SAY "Enter the DBC logon for the TARGET DBC in the form:" 
      SAY "         tdp/user" 
      PARSE UPPER EXTERNAL transtlog 
      IF transtlog = "QUIT" THEN EXIT 
      END 
   transtlog = ChooseLogon 
   transtlog = logon.transtlog.string 
   "CLEAR" 
   SAY "**  OPTION  X  -  (DDL Transfer)  **" 
   SAY "" 
   SAY "Enter the TARGET (TO) databasename:" 
   PARSE UPPER EXTERNAL transtarget 
   IF transtarget = "QUIT"  THEN EXIT 

   transverb = 0 
   IF INDEX(transkind, 'T') = 0 THEN 
      DO 
      SAY " " 
      SAY "Enter item number for the action desired:" 
      SAY "            1)  Use CREATE  in all DDL" 
      SAY "            2)  Use REPLACE in all DDL" 
      PARSE UPPER EXTERNAL transverb 
      IF transverb = "QUIT"  THEN EXIT 
      END 
   RETURN 

   -------------------------------------------------------------------*/ 
/*  FINDDDLNAME - Get specific DDL for transfer                       */ 
/*--------------------------------------------------------------------*/ 
FINDDDLNAME: 
   SAY "" 
   SELECT 
      WHEN transkind = "T1" THEN SAY "Enter tablename for transfer:" 
      WHEN transkind = "V1" THEN SAY "Enter viewname  for transfer:" 
      WHEN transkind = "M1" THEN SAY "Enter macroname for transfer:" 
      OTHERWISE  NOP 
      END 
   PARSE UPPER EXTERNAL transname 
   IF transname = "QUIT" THEN EXIT 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DORES1 - Get RESUSAGE Specifics                                   */ 
/*--------------------------------------------------------------------*/ 
DORES1: 
   res = 1 
   "CLEAR" 
   SAY "You have indicated that resusage reports be run. Enter a " 
   SAY "string of letters.  One letter for each report you would" 
   SAY "like: (Each uses the initial Date/Time option values)" 
   SAY "" 
   SAY " A = ResNode                                C = ResNetByNode" 
   SAY " D = ResCPUByAMP       E = ResCPUByPE       F = ResCPUByNode" 
   SAY " G = ResHostByLink     H = ResLdvByNode     I = ResMemMgmtByNode" 
   SAY "" 
   PARSE UPPER EXTERNAL resin 
   IF resin = "QUIT"  THEN EXIT 


   resnumflg = 0 

   SAY "" 
   SAY "For disk information on each drive, enter:" 
   SAY "      a)  a blank line for all AMPs" 
   SAY "  or  b)  'c-p' for a processor number" 
   SAY "          (where 'c' = cabinet and 'p' = processor)" 
   PARSE UPPER EXTERNAL resresp 
   SELECT 
      WHEN resresp = "QUIT"  THEN EXIT 
      WHEN resresp = ''      THEN NOP 
      OTHERWISE DO 
         resinnum = resresp 
         resnumflg = 1 
         END 
      END 
   PARSE VAR resresp p1 '-' p2 
   IF p2 = 10 THEN 
      p2 = 2 
   resresp = "'"RIGHT("000"p1,3)"-"RIGHT("00"p2,2)"'" 

   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DODDL1 - Get DDL Specifics                                        */ 
/*--------------------------------------------------------------------*/ 
DODDL1: 
   DO FOREVER 
      "CLEAR" 
      SAY "   **  OPTION D  -  Get DDL  **" 
      SAY "" 
      SAY "You have indicated that all DDL for a database" 
      SAY "be collected.  Please enter the database name:" 
      PARSE UPPER EXTERNAL dbname 
      SELECT 
         WHEN dbname = 'QUIT' THEN EXIT 
         WHEN dbname = ''     THEN NOP 
         OTHERWISE DO 
            ddlflag = 1 
            LEAVE 
            END 
         END 
      END 

   DO FOREVER 
      SAY "" 
      SAY "If you would like only VIEW  DDL enter 'V'; " 
      SAY "If you would like only TABLE DDL enter 'T'; " 
      SAY "If you would like only MACRO DDL enter 'M'; " 
      SAY "If you would like all three enter a blank line." 
      PARSE UPPER EXTERNAL tvmkind 
      SELECT 
         WHEN tvmkind = "QUIT"   THEN EXIT 
         WHEN tvmkind = ""       THEN LEAVE 
         WHEN tvmkind = "T"      THEN LEAVE 
         WHEN tvmkind = "V"      THEN LEAVE 
         WHEN tvmkind = "M"      THEN LEAVE 
         OTHERWISE  NOP 
         END 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOD2W1 - Get Date for Day of Week Conversion                      */ 
/*--------------------------------------------------------------------*/ 
DOD2W1: 
   "CLEAR" 
   SAY "You have indicated that a Day of Week be found" 
   SAY "for a date." 
   SAY "    => Enter YYMMDD to convert to day" 
   SAY " or => Enter a blank line to convert the Start/End dates" 
   PARSE UPPER EXTERNAL dcon 
   IF dcon = "QUIT" THEN EXIT 
   SELECT 
      WHEN dcon = "" THEN 
         DO 
         dconv.0 = " " 
         dconv.1 = sdate 
         dconv.2 = edate 
         d2w = 1 
         END 
      OTHERWISE DO 
         dconv.0 = dcon 
         dconv.1 = " " 
         dconv.2 = " " 
         d2w = 1 
         END 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOFB1 - Get Fallback Statistics                                   */ 
/*--------------------------------------------------------------------*/ 
DOFB1: 
   DO FOREVER 
      "CLEAR" 
      SAY "You have indicated that Fallback and Journal information" 
      SAY "for each table in a database be listed.  Enter the " 
      SAY "database name:" 
      PARSE UPPER EXTERNAL fbdb 
      IF fbdb = QUIT THEN EXIT 
      SELECT 
         WHEN fbdb = ''   THEN NOP 
         OTHERWISE DO 
           fb = 1 
           LEAVE 
           END 
        END 
     END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOINDX1 - Get Index Specifics                                     */ 
/*--------------------------------------------------------------------*/ 
DOINDX1: 
   DO FOREVER 
      "CLEAR" 
      SAY "You have indicated that Index information for each" 
      SAY "table in a database be listed.  Enter the database name:" 
      PARSE UPPER EXTERNAL ixdb 
      IF ixdb = QUIT THEN EXIT 
      SELECT 
         WHEN ixdb = ''   THEN NOP 
         OTHERWISE DO 
           indx = 1 
           LEAVE 
           END 
        END 
     END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOUSR1 - Get AccessRights for User Info                           */ 
/*--------------------------------------------------------------------*/ 
DOUSR1: 
   rgt = 1 
   "CLEAR" 
   SAY "You have indicated that AccessRights for a user" 
   SAY "be listed.  Enter the user name:" 
   PARSE UPPER EXTERNAL usrin 
   IF usrin = QUIT THEN EXIT 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DODBHELP1 - Get Database Help Info                                */ 
/*--------------------------------------------------------------------*/ 
DODBHELP1: 
   dhp = 1 
   "CLEAR" 
   SAY "You have indicated that Help Information on a database" 
   SAY "be listed.  Enter the database name:" 
   PARSE UPPER EXTERNAL dbhin 
   IF dbhin = QUIT THEN EXIT 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOV1 - Get AccessRights on Database Info                          */ 
/*--------------------------------------------------------------------*/ 
DOV1: 
   rgtv = 1 
   "CLEAR" 
   SAY "You have indicated that AccessRights on a database" 
   SAY "be listed.  Enter the database name:" 
   PARSE UPPER EXTERNAL dbvin 
   IF dbvin = QUIT THEN EXIT 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOACCT1 - Get accounting specifics                                */ 
/*--------------------------------------------------------------------*/ 
DOACCT1: 
   act = 1 
   "CLEAR" 
   SAY "You have indicated that General User information for a" 
   SAY "DBC User be listed.  Enter the Username:" 
   PARSE UPPER EXTERNAL actusr 
   IF actusr = QUIT THEN EXIT 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOTREE1 - Get TREE Specifics                                      */ 
/*--------------------------------------------------------------------*/ 
DOTREE1: 
   tre = 1 
   "CLEAR" 
   SAY "You have indicated that you would like a TREE" 
   SAY "structure for a DBC Hierarchy.  Enter the" 
   SAY "databasename for which the tree should begin." 
   SAY "" 
   SAY "A blank line means begin at database DBC." 
   PARSE UPPER EXTERNAL tredb 
   IF tredb = QUIT THEN EXIT 
   IF tredb = ''   THEN tredb = "DBC" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOSPC - Prompt for spaceing report                                */ 
/*--------------------------------------------------------------------*/ 
DOSPC: 
   DO FOREVER 
      "CLEAR" 
      SAY "You have indicated that space reports be run. Enter a string" 
      SAY "of letters, one letter for each report you would like:" 
      SAY "" 
      SAY "  A = Perm space by database for entire DBC" 
      SAY "  B = Perm by AMP for a Database" 
      SAY "  C = Perm by AMP for a Table" 
      SAY "  D = Perm skew for all tables in a Database" 
      SAY "  E = Perm summary for each table in a Database" 
      SAY "  F = Current spool usage for each User" 
      SAY "  G = Max Spool defined for each User" 
      PARSE UPPER EXTERNAL spcin 
      IF spcin = "QUIT"  THEN EXIT 
      IF INDEX(spcin,'A') > 0  THEN spcprm  = 1 
      IF INDEX(spcin,'B') > 0  THEN spcpctd = 1 
      IF INDEX(spcin,'C') > 0  THEN spcpctt = 1 
      IF INDEX(spcin,'D') > 0  THEN spcpcts = 1 
      IF INDEX(spcin,'E') > 0  THEN spcprms = 1 
      IF INDEX(spcin,'F') > 0  THEN spcspl  = 1 
      IF INDEX(spcin,'G') > 0  THEN spcsplx = 1 

      IF spcprm  = 1  THEN LEAVE 
      IF spcpctd = 1  THEN LEAVE 
      IF spcpctt = 1  THEN LEAVE 
      IF spcpcts = 1  THEN LEAVE 
      IF spcprms = 1  THEN LEAVE 
      IF spcspl  = 1  THEN LEAVE 
      IF spcsplx = 1  THEN LEAVE 
      END 

   "CLEAR" 
   IF spcpctd = 1  THEN 
      DO 
      SAY "For permspace by AMP for a Database," 
      SAY "enter the databasename now:" 
      PARSE UPPER EXTERNAL dtldb 
      IF dtldb = "QUIT"  THEN EXIT 
      END 
   IF spcpctt = 1  THEN 
      DO 
      SAY "For permspace by AMP for a Table," 
      SAY "enter the tablename now:" 
      PARSE UPPER EXTERNAL dtltb 
      IF dtltb = "QUIT"  THEN EXIT 
      END 
   IF spcprms = 1  THEN 
      DO 
      SAY "For perm summary for Tables in a Database," 
      SAY "enter the databasename now:" 
      PARSE UPPER EXTERNAL sumdb 
      IF sumdb = "QUIT"  THEN EXIT 
      END 
   IF spcpcts = 1  THEN 
      DO 
      SAY "For perm skew for all tables in a Database," 
      SAY "enter the databasename now:" 
      PARSE UPPER EXTERNAL pctdb 
      IF pctdb = "QUIT"  THEN EXIT 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOERR1 - Get Errorlog options                                     */ 
/*--------------------------------------------------------------------*/ 
DOERR1: 
   DO FOREVER 
      "CLEAR" 
      SAY "You have indicated that you would like an" 
      SAY "ERRORLOG Report run. Enter any combination" 
      SAY "of reports below by its associated letter." 
      SAY "" 
      SAY "     A = Standard Errorlog Report" 
      SAY "     B = Specific Events Report" 
      SAY "     C = Crashable Events Report" 
      PARSE UPPER EXTERNAL errstring 
      IF errstring = "QUIT"        THEN EXIT 
      IF INDEX(errstring,'A') > 0  THEN LEAVE 
      IF INDEX(errstring,'B') > 0  THEN LEAVE 
      IF INDEX(errstring,'C') > 0  THEN LEAVE 
      END 
   IF INDEX(errstring,'B') > 0     THEN CALL doevl1 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOEVL1 - Get Event Prefix Specifics                               */ 
/*--------------------------------------------------------------------*/ 
DOEVL1: 
   DO FOREVER 
      "CLEAR" 
      SAY "You have indicated that occurrances of errorlog events" 
      SAY "be reported according to ranges of events. Enter any of" 
      SAY "the leading digits for events you need:" 
      SAY "" 
      SAY "For example: 71 would retrieve any 71xx event," 
      SAY "             NOT any event containing '71'." 
      PARSE UPPER EXTERNAL evnt 
      IF evnt = 'QUIT' THEN EXIT 
      IF DATATYPE(evnt) = "NUM" THEN 
         DO 
         IF evnt < 10 THEN 
            DO 
            evnt1 = evnt  * 1000 
            evnt2 = evnt1 + 999 
            evntx = evnt"xxx" 
            evntq = 0 
            evtf = 1 
            LEAVE 
            END 
         IF evnt < 100 THEN 
            DO 
            evnt1 = evnt  * 100 
            evnt2 = evnt1 + 99 
            evntx = evnt"xx" 
            evntq = 0 
            evtf = 1 
            LEAVE 
            END 
         IF evnt < 1000 THEN 
            DO 
            evnt1 = evnt  * 10 
            evnt2 = evnt1 + 9 
            evntx = evnt"x" 
            evntq = 0 
            evtf = 1 
            LEAVE 
            END 
         IF evnt < 10000 THEN 
            DO 
            evntx = evnt 
            evntq = 1 
            evtf = 1 
            LEAVE 
            END 
         END 
      END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*---------------------- PHASE 2 - Generate SQL ----------------------*/ 
/*--------------------------------------------------------------------*/ 

/*--------------------------------------------------------------------*/ 
/*  DOARC - Queue the ARC Report SQL                                  */ 
/*--------------------------------------------------------------------*/ 
DOARC: 
   arc = 1 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set width 85" 
   QUEUE ".set suppress on 1, 2, 3" 
   QUEUE ".set rtitle 'Dump/restore between "sdatex" and "edatex"'" 
   QUEUE ".set foldline on 1" 
   QUEUE ".export report ddname=rptarc" 
   QUEUE "" 
   QUEUE "select createdate   (title 'Create//Date')," 
   QUEUE "       eventtype    (char(10))," 
   QUEUE "       databasename (char(15))," 
   QUEUE "       tablename    (char(15))," 
   QUEUE "       objecttype   (title 'TVM?', format 'x(4)')," 
   QUEUE "       createtime   (title 'Create//Time')," 
   QUEUE "       operationinprocess (title 'Active?')" 
   QUEUE "  from dbc.events" 
   QUEUE " where ((createdate = "sdate" and createtime >= "stime")" 
   QUEUE "    or  (createdate > "sdate"))" 
   QUEUE "   and ((createdate = "edate" and createtime <= "etime")" 
   QUEUE "    or  (createdate < "edate"))" 
   QUEUE "order by 1, 3, 6;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOERR2 - Queue the ERR Report SQL                                 */ 
/*--------------------------------------------------------------------*/ 
DOERR2: 
   err = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 85" 
   QUEUE ".set rtitle 'Errorlog info between "sdatex" and "edatex"'" 
   QUEUE ".set suppress on 1, 2, 3, 4, 5" 
   QUEUE ".set foldline on 1, 5" 
   QUEUE ".set underline on 2" 
   QUEUE ".export report ddname=rpterr" 
   QUEUE "" 
   QUEUE "select thedate," 
   QUEUE "       trim(substr(thetime, 1, 8)) ]] ' /' ]] event_tag" 
   QUEUE "           (title 'Time / Event')," 
   QUEUE "       pma (title 'Node'), vproc, severity," 
   QUEUE "       text" 
   QUEUE "  from dbc.software_event_log" 
   QUEUE " where ((thedate = "sdate" and thetime >= "stime")" 
   QUEUE "    or  (thedate > "sdate"))" 
   QUEUE "   and ((thedate = "edate" and thetime <= "etime")" 
   QUEUE "    or  (thedate < "edate"))" 
   QUEUE "   and Severity is not null" 
   QUEUE "   and text <> ''" 
   QUEUE " order by" 
   QUEUE "       thedate, thetime, event_tag, pma, vproc, severity, line;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOTRANS2 - Queue the DDL Transfer SQL                             */ 
/*--------------------------------------------------------------------*/ 
DOTRANS2: 
   QUEUE ".set defaults" 
   QUEUE ".set titledashes off" 
   QUEUE ".set underline off" 
   QUEUE ".export data ddname=runshows" 
   QUEUE "select '"logonstring"'                (char(30), title '');" 
   QUEUE "select '.set defaults'                (char(30), title '');" 
   QUEUE "select '.set underline off'           (char(30), title '');" 
   QUEUE "select '.set titledashes off'         (char(30), title '');" 
   QUEUE "select '.export report ddname=runddl' (char(30), title '');" 
   QUEUE "select 'database "transsource";'      (char(40), title '');" 
   c60 = "(char(60), title '');" 
   IF transdescr = 1 THEN 
      DO 
      QUEUE "sel 'sel ''"logonstring"''" 
      QUEUE "    (char(30), title '''');' "c60 
      END 
   IF transdescr = 2 THEN 
      DO 
      QUEUE "sel 'sel ''"transtlog"''" 
      QUEUE "    (char(30), title '''');' "c60 
      END 
   QUEUE "sel 'sel ''database "transtarget";'' " 
   QUEUE "     (char(30), title '''');' "c60 
   IF INDEX(transkind, 'T') > 0 THEN 
      DO 
      QUEUE "select 'show table ' (char(20), title '')," 
      QUEUE "       tablename     (char(30), title '')," 
      QUEUE "       ';'           (char(01), title '')" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"transsource"'" 
      QUEUE "   and tablekind    = 't'" 
      IF transkind = 'T1' THEN 
         QUEUE "   and tablename = '"transname"'" 
      QUEUE " order by 2;" 
      END 
   IF INDEX(transkind, 'V') > 0 THEN 
      DO 
      QUEUE "select 'show view  ' (char(20), title '')," 
      QUEUE "       tablename     (char(30), title '')," 
      QUEUE "       ';'           (char(01), title '')" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"transsource"'" 
      QUEUE "   and tablekind    = 'v'" 
      IF transkind = 'V1' THEN 
         QUEUE "   and tablename = '"transname"'" 
      QUEUE " order by 2;" 
      END 
   IF INDEX(transkind, 'M') > 0 THEN 
      DO 
      QUEUE "select 'show macro ' (char(20), title '')," 
      QUEUE "       tablename     (char(30), title '')," 
      QUEUE "       ';'           (char(01), title '')" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"transsource"'" 
      QUEUE "   and tablekind    = 'm'" 
      IF transkind = 'M1' THEN 
         QUEUE "   and tablename = '"transname"'" 
      QUEUE " order by 2;" 
      END 
   QUEUE "sel '.export reset'     (char(30), title '');" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOTC2 - Queue the Column Info SQL                                 */ 
/*--------------------------------------------------------------------*/ 
DOTC2: 
   tc = 1 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 80" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set foldline on 3" 
   QUEUE ".set rtitle 'Table/Column Information//For All Tables//-" 
   QUEUE         "In Database "tcans"'" 
   QUEUE ".export report ddname=rpttc" 
   QUEUE "locking dbc.tvfields for access" 
   QUEUE "locking dbc.tvm      for access" 
   QUEUE "locking dbc.dbase    for access" 
   QUEUE "select b.tvmnamei" 
   QUEUE "          (title 'Table Name', char(20))," 
   QUEUE "       count(a.fieldid)" 
   QUEUE "          (title 'Cols', format 'zz9')," 
   QUEUE "       sum(a.maxlength)" 
   QUEUE "          (title 'Row//Size', format 'zz9')," 
   QUEUE "       sum(index(a.compressible, 'c'))" 
   QUEUE "          (title 'Cmpr//Col', format 'zz9')," 
   QUEUE "       sum(index(a.nullable, 'y'))" 
   QUEUE "          (title 'Null//Col', format 'zz9')," 
   QUEUE "       sum(index(a.uppercaseflag, 'y'))" 
   QUEUE "          (title 'UpCs//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'bf'))" 
   QUEUE "          (title 'F-B//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'bv'))" 
   QUEUE "          (title 'V-B//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'cf'))" 
   QUEUE "          (title 'F-C//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'cv'))" 
   QUEUE "          (title 'V-C//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'd '))" 
   QUEUE "          (title 'Dec//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'da'))" 
   QUEUE "          (title 'Dte//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'f '))" 
   QUEUE "          (title 'Flt//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'i '))" 
   QUEUE "          (title 'Int//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'i1'))" 
   QUEUE "          (title 'B-I//Col', format 'zz9')," 
   QUEUE "       sum(index(a.fieldtype, 'i2'))" 
   QUEUE "          (title 'S-I//Col', format 'zz9')" 
   QUEUE "  from dbc.tvfields a, dbc.tvm b, dbc.dbase c" 
   QUEUE " where a.tableid       = b.tvmid" 
   QUEUE "   and a.databaseid    = b.databaseid" 
   QUEUE "   and a.databaseid    = c.databaseid" 
   QUEUE "   and c.databasenamei = '"tcans"'" 
   QUEUE " group by 1" 
   QUEUE " order by 1;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOLGN2 - QUeue the LGN Report SQL                                 */ 
/*--------------------------------------------------------------------*/ 
DOLGN2: 
   lgn = 1 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE feets 
   QUEUE ".set width 80" 
   QUEUE ".export report ddname=rptlgn" 
   IF INDEX(lgnopt, '2') > 0 THEN 
      DO 
      QUEUE "" 
      QUEUE ".set foldline on 1" 
      QUEUE ".set rtitle 'LogonOff info between "sdatex" and "edatex"'" 
      QUEUE ".set suppress on 1, 2, 3, 4" 
      QUEUE "" 
      QUEUE "locking dbc.logonoff for access" 
      QUEUE "select username      (char(15))," 
      QUEUE "       logdate," 
      QUEUE "       logonsource   (char(14))," 
      QUEUE "       logicalhostid]]'/']]substr(ifpno,3,3)" 
      QUEUE "                     (title 'Host/IFP')," 
      QUEUE "       event         (format 'x(8)')," 
      QUEUE "       sessionno     (title 'Ses#', format 'zzz,zz9')," 
      QUEUE "       logtime" 
      QUEUE "  from dbc.logonoff" 
      QUEUE " where ((logdate = "sdate" and logtime >= "stime")" 
      QUEUE "    or  (logdate > "sdate"))" 
      QUEUE "   and ((logdate = "edate" and logtime <= "etime")" 
      QUEUE "    or  (logdate < "edate"))" 
      QUEUE " order by 2, 7;" 
      END 
   DO i = 3 TO 6 
      IF INDEX(lgnopt, i) > 0 THEN 
         DO 
         QUEUE ".set defaults" 
         QUEUE ".set format on" 
         QUEUE ".set width 80" 
         SELECT 
            WHEN i = 3 THEN 
               QUEUE ".set rtitle 'Logons - UserByHour between", 
                      editit(t11,':')" and "editit(t26,':')"'" 
            WHEN i = 4 THEN 
               QUEUE ".set rtitle 'Logons - IFP-ByHour between", 
                      editit(t11,':')" and "editit(t26,':')"'" 
            WHEN i = 5 THEN 
               DO 
               QUEUE ".set rtitle 'Logons - HostByHour between", 
                      editit(t11,':')" and "editit(t26,':')"'" 
               QUEUE feets 
               END 
            WHEN i = 6 THEN 
               DO 
               QUEUE ".set rtitle 'Logons - User/HostByHour between ", 
                      editit(t11,':')" and "editit(t26,':')"'" 
               QUEUE feets 
               END 
            OTHERWISE NOP 
            END 
         SELECT 
            WHEN i = 3 THEN 
               QUEUE "select username (char(20))," 
            WHEN i = 4 THEN 
               QUEUE "select ifpno," 
            WHEN i = 5 THEN 
               QUEUE "select logicalhostid (title 'Host ID')," 
            WHEN i = 6 THEN 
               DO 
               QUEUE ".set suppress on 1" 
               QUEUE "select logicalhostid (title 'Host ID')," 
               QUEUE "       username      (char(20))," 
               END 
            OTHERWISE  NOP 
            END 
         QUEUE "    sum(((abs(logtime-"t11")+(logtime-"t11")+2)  mod" 
         QUEUE "         (abs(logtime-"t11")+(logtime-"t11")+1))  + " 
         QUEUE "        ((abs("t21"-logtime)+("t21"-logtime)+2)  mod" 
         QUEUE "         (abs("t21"-logtime)+("t21"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '00 -//01am', format 'zz,zz9')," 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '06 -//07am', format 'zz,zz9')," 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '12 -//01pm', format 'zz,zz9')," 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '06 -//07pm', format 'zz,zz9')," 
            OTHERWISE  NOP 
            END 

         QUEUE "    sum(((abs(logtime-"t12")+(logtime-"t12")+2)  mod" 
         QUEUE "         (abs(logtime-"t12")+(logtime-"t12")+1))  + " 
         QUEUE "        ((abs("t22"-logtime)+("t22"-logtime)+2)  mod" 
         QUEUE "         (abs("t22"-logtime)+("t22"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '01 -//02am', format 'zz,zz9')," 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '07 -//08am', format 'zz,zz9')," 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '01 -//02pm', format 'zz,zz9')," 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '07 -//08pm', format 'zz,zz9')," 
            OTHERWISE  NOP 
            END 

         QUEUE "    sum(((abs(logtime-"t13")+(logtime-"t13")+2)  mod" 
         QUEUE "         (abs(logtime-"t13")+(logtime-"t13")+1))  + " 
         QUEUE "        ((abs("t23"-logtime)+("t23"-logtime)+2)  mod" 
         QUEUE "         (abs("t23"-logtime)+("t23"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '02 -//03am', format 'zz,zz9')," 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '08 -//09am', format 'zz,zz9')," 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '02 -//03pm', format 'zz,zz9')," 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '08 -//09pm', format 'zz,zz9')," 
            OTHERWISE  NOP 
            END 

         QUEUE "    sum(((abs(logtime-"t14")+(logtime-"t14")+2)  mod" 
         QUEUE "         (abs(logtime-"t14")+(logtime-"t14")+1))  + " 
         QUEUE "        ((abs("t24"-logtime)+("t24"-logtime)+2)  mod" 
         QUEUE "         (abs("t24"-logtime)+("t24"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '03 -//04am', format 'zz,zz9')," 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '09 -//10am', format 'zz,zz9')," 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '03 -//04pm', format 'zz,zz9')," 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '09 -//10pm', format 'zz,zz9')," 
            OTHERWISE  NOP 
            END 

         QUEUE "    sum(((abs(logtime-"t15")+(logtime-"t15")+2)  mod" 
         QUEUE "         (abs(logtime-"t15")+(logtime-"t15")+1))  + " 
         QUEUE "        ((abs("t25"-logtime)+("t25"-logtime)+2)  mod" 
         QUEUE "         (abs("t25"-logtime)+("t25"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '04 -//05am', format 'zz,zz9')," 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '10 -//11am', format 'zz,zz9')," 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '04 -//05pm', format 'zz,zz9')," 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '10 -//11pm', format 'zz,zz9')," 
            OTHERWISE  NOP 
            END 

         QUEUE "    sum(((abs(logtime-"t16")+(logtime-"t16")+2)  mod" 
         QUEUE "         (abs(logtime-"t16")+(logtime-"t16")+1))  + " 
         QUEUE "        ((abs("t26"-logtime)+("t26"-logtime)+2)  mod" 
         QUEUE "         (abs("t26"-logtime)+("t26"-logtime)+1)) - 1)" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "        (title '05 -//06am', format 'zz,zz9')" 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "        (title '11 -//12pm', format 'zz,zz9')" 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "        (title '05 -//06pm', format 'zz,zz9')" 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "        (title '11 -//12am', format 'zz,zz9')" 
            OTHERWISE  NOP 
            END 
         QUEUE "  from dbc.logonoff" 
         QUEUE " where event = 'logon'" 
         QUEUE "   and ((logdate >= "sdate" and logdate <= "edate")" 
         SELECT 
            WHEN lgnoptpd = 1 THEN 
               QUEUE "   and (logtime >= 000000 and logtime < 060000))" 
            WHEN lgnoptpd = 2 THEN 
               QUEUE "   and (logtime >= 060000 and logtime < 120000))" 
            WHEN lgnoptpd = 3 THEN 
               QUEUE "   and (logtime >= 120000 and logtime < 180000))" 
            WHEN lgnoptpd = 4 THEN 
               QUEUE "   and (logtime >= 180000 and logtime < 240000))" 
            OTHERWISE  NOP 
            END 
         IF i = 6 THEN 
            DO 
            QUEUE " group by 1, 2" 
            QUEUE " order by 1, 2;" 
            END 
         ELSE 
            DO 
            QUEUE " group by 1" 
            QUEUE " order by 1;" 
            END 
         END 
      END 
   IF INDEX(lgnopt, 1) > 0 THEN 
      DO 
      CALL adjdates 
      QUEUE ".set defaults" 
      QUEUE ".set width 120" 
      QUEUE ".set suppress on 1, 2" 
      QUEUE ".set rtitle 'Active Users: "sdatex"-"stimex" to ", 
                  edatex"-"etimex"'" 
      QUEUE "locking dbc.logonoff for access" 
      QUEUE "select username, logondate, logontime" 
      QUEUE "      ,sessionno, logonsource (CHAR(50))" 
      QUEUE "  from dbc.logonoff" 
      QUEUE " where event = 'logon'" 
      QUEUE "   and ((logdate = "prevdate" and logtime >= "stime")" 
      QUEUE "    or  (logdate > "prevdate"))" 
      QUEUE "   and ((logdate = "edate" and logtime <= "etime")" 
      QUEUE "    or  (logdate < "edate"))" 
      QUEUE "minus" 
      QUEUE "select username, logondate, logontime" 
      QUEUE "      ,sessionno, logonsource (CHAR(50))" 
      QUEUE "  from dbc.logonoff" 
      QUEUE " where event = 'logoff'" 
      QUEUE "   and ((logdate = "prevdate" and logtime >= "stime")" 
      QUEUE "    or  (logdate > "prevdate"))" 
      QUEUE "   and ((logdate = "sdate" and logtime <= "stime")" 
      QUEUE "    or  (logdate < "sdate"))" 
      QUEUE " order by 1, 2, 3;" 
      END 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  ADJDATES - Queue the SES Report SQL                               */ 
/*--------------------------------------------------------------------*/ 
ADJDATES: 
/*-------------------*/ 
/*  Find Prevdate    */ 
/*-------------------*/ 
   aaa1 = sdate - 1 
   yyy1 = substr(aaa1, 1, 2) 
   mmm1 = substr(aaa1, 3, 2) 
   ddd1 = substr(aaa1, 5, 2) 
   IF ddd1 = 0 THEN 
      mmm1 = mmm1 - 1 
   IF mmm1 = 0 THEN 
      DO 
      mmm1 = 12 
      yyy1 = yyy1 - 1 
      END 
   IF ddd1 = 0 THEN 
      DO 
      SELECT 
         WHEN mmm1 = 1    THEN ddd1 = 31 
         WHEN mmm1 = 2    THEN 
            DO 
            IF yyy1 // 4 = 0 THEN 
               ddd1 = 29 
            ELSE 
               ddd1 = 28 
            END 
         WHEN mmm1 = 3    THEN ddd1 = 31 
         WHEN mmm1 = 4    THEN ddd1 = 30 
         WHEN mmm1 = 5    THEN ddd1 = 31 
         WHEN mmm1 = 6    THEN ddd1 = 30 
         WHEN mmm1 = 7    THEN ddd1 = 31 
         WHEN mmm1 = 8    THEN ddd1 = 31 
         WHEN mmm1 = 9    THEN ddd1 = 30 
         WHEN mmm1 = 10   THEN ddd1 = 31 
         WHEN mmm1 = 11   THEN ddd1 = 30 
         WHEN mmm1 = 12   THEN ddd1 = 31 
         OTHERWISE  NOP 
         END 
      END 
   IF LENGTH(mmm1) = 1 THEN  mmm1 = "0"mmm1 
   IF LENGTH(ddd1) = 1 THEN  ddd1 = "0"ddd1 

/*-------------------*/ 
/*  Find PostDate    */ 
/*-------------------*/ 
   aaa2 = edate + 1 
   yyy2 = substr(aaa2, 1, 2) 
   mmm2 = substr(aaa2, 3, 2) 
   ddd2 = substr(aaa2, 5, 2) 
   IF ddd2 = 32 THEN 
      ddd2 = 1 
   IF ddd2 = 29 THEN 
      DO 
      IF mmm2 = 2 THEN 
         IF yyy2 // 4 > 0 THEN 
            ddd2 = 1 
      END 
   IF ddd2 > 29 THEN 
      DO 
      IF mmm2 = 2 THEN 
         IF yyy2 // 4 = 0 THEN 
            ddd2 = 1 
      END 
   IF ddd2 = 31 THEN 
      DO 
      SELECT 
         WHEN mmm2 = 4    THEN ddd2 = 1 
         WHEN mmm2 = 6    THEN ddd2 = 1 
         WHEN mmm2 = 9    THEN ddd2 = 1 
         WHEN mmm2 = 11   THEN ddd2 = 1 
         OTHERWISE  NOP 
         END 
      END 
   IF ddd2 = 1 THEN 
      mmm2 = mmm2 + 1 
   IF mmm2 > 12 THEN 
      DO 
      mmm2 = 1 
      yyy2 = yyy2 + 1 
      END 
   IF LENGTH(mmm2) = 1 THEN  mmm2 = "0"mmm2 
   IF LENGTH(ddd2) = 1 THEN  ddd2 = "0"ddd2 

   prevdate = yyy1""mmm1""ddd1 
   postdate = yyy2""mmm2""ddd2 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOSES - Queue the SES Report SQL                                  */ 
/*--------------------------------------------------------------------*/ 
DOSES: 
   ses = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 90" 
   QUEUE ".set rtitle 'SessionInfo Report on Current Users'" 
   QUEUE feets 
   QUEUE ".export report ddname=rptses" 
   QUEUE "" 
   QUEUE "select username (char (10)), logonsource (char(10))," 
   QUEUE "       ifpno, hostno, sessionno, defaultdatabase" 
   QUEUE "       (title 'Default', char(10))" 
   QUEUE "  from dbc.sessioninfo order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOX - Queue the SERIOUS EVENTS REPORT                             */ 
/*--------------------------------------------------------------------*/ 
DOX: 
   dox = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Serious Events between "sdatex" and "edatex"'" 
   QUEUE ".set width 80" 
   QUEUE ".export report ddname=rptdox" 
   QUEUE "locking dbc.errorlog for access" 
   QUEUE "select errdate," 
   QUEUE "       substr(text, 2, 4)   (title 'Text//Event')," 
   QUEUE "       count(*)             (title 'Count', format 'zz9')," 
   QUEUE "       substr(text, 8)      (title 'Text')" 
   QUEUE "  from dbc.errorlog" 
   QUEUE " where ((errdate = "sdate" and errtime >= "stime")" 
   QUEUE "    or  (errdate > "sdate"))" 
   QUEUE "   and ((errdate = "edate" and errtime <= "etime")" 
   QUEUE "    or  (errdate < "edate"))" 
   QUEUE "   and   linenumber = 5" 
   QUEUE "   and   event in (2006, 2008)" 
   QUEUE " group by 1, 2, 4" 
   QUEUE "UNION" 
   QUEUE "select errdate," 
   QUEUE "       substr(text, 2, 4)   (title 'Text//Event')," 
   QUEUE "       count(*)             (title 'Count', format 'zz9')," 
   QUEUE "       substr(text, 8)      (title 'Text')" 
   QUEUE "  from dbc.errorlog" 
   QUEUE " where ((errdate = "sdate" and errtime >= "stime")" 
   QUEUE "    or  (errdate > "sdate"))" 
   QUEUE "   and ((errdate = "edate" and errtime <= "etime")" 
   QUEUE "    or  (errdate < "edate"))" 
   QUEUE "   and   linenumber = 6" 
   QUEUE "   and   event      = 2009" 
   QUEUE " group by 1, 2, 4" 
   QUEUE "UNION" 
   QUEUE "select errdate," 
   QUEUE "       substr(text, 2, 4)   (title 'Text//Event')," 
   QUEUE "       count(*)             (title 'Count', format 'zz9')," 
   QUEUE "       substr(text, 8)      (title 'Text', named t1)" 
   QUEUE "  from dbc.errorlog" 
   QUEUE " where ((errdate = "sdate" and errtime >= "stime")" 
   QUEUE "    or  (errdate > "sdate"))" 
   QUEUE "   and ((errdate = "edate" and errtime <= "etime")" 
   QUEUE "    or  (errdate < "edate"))" 
   QUEUE "   and   linenumber = 2" 
   QUEUE "   and   event      = 2015" 
   QUEUE "   and   t1 like '%unusual%'" 
   QUEUE " group by 1, 2, 4" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOPRM - Queue the PERM SPACE Report SQL                           */ 
/*--------------------------------------------------------------------*/ 
DOPRM: 
   prm = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Perm Space Report'" 
   QUEUE ".set width 95" 
   QUEUE ".export report ddname=rptprm" 
   QUEUE "locking dbc.databases for access" 
   QUEUE "locking dbc.diskspace for access" 
   QUEUE "select a.ownername    (char(12), title 'Owner')," 
   QUEUE "       b.databasename (char(12), title 'Database')," 
   QUEUE "       sum(b.currentperm)" 
   QUEUE "           (title 'Current//Perm', format 'zzz,zzz,zzz,zzz,zz9')," 
   QUEUE "       sum(b.maxperm)" 
   QUEUE "           (title 'Max//Perm', format 'zzz,zzz,zzz,zzz,zz9')," 
   QUEUE "       avg(b.currentperm)/nullifzero(avg(b.maxperm))*100" 
   QUEUE "           (title 'Pct//Full', format 'zz9.9')," 
   QUEUE "       max(b.currentperm)/nullifzero(avg(b.maxperm))*100" 
   QUEUE "           (title 'Max//Pct//Full', format 'zz9.9')" 
   QUEUE "  from dbc.databases a, dbc.diskspace b" 
   QUEUE " where a.databasename = b.databasename" 
   QUEUE "   and b.maxperm      > 0" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2" 
   QUEUE "  with sum(currentperm)" 
   QUEUE "       (title 'By Owner:', format 'zzz,zzz,zzz,zzz,zz9')," 
   QUEUE "       sum(maxperm)" 
   QUEUE "       (title '', format 'zzz,zzz,zzz,zzz,zz9')" 
   QUEUE "    by a.ownername" 
   QUEUE "  with sum(currentperm)" 
   QUEUE "       (title '', format 'zzz,zzz,zzz,zzz,zz9')," 
   QUEUE "       sum(maxperm)" 
   QUEUE "       (title '', format 'zzz,zzz,zzz,zzz,zz9');" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOSPLX - Queue the Max Spool Report SQL                           */ 
/*--------------------------------------------------------------------*/ 
DOSPLX: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Max Spool Report'" 
   QUEUE ".set width 80" 
   QUEUE ".export report ddname=rptsplx" 
   QUEUE "locking dbc.databases for access" 
   QUEUE "locking dbc.diskspace for access" 
   QUEUE "select a.ownername      (char(12), title 'Owner')," 
   QUEUE "       b.databasename   (char(12), title 'Database')," 
   QUEUE "       sum(b.maxspool)" 
   QUEUE "           (title 'Max//Spool', format 'zzzz,zzz,zzz,999')" 
   QUEUE "  from dbc.databases a, dbc.diskspace b" 
   QUEUE " where a.databasename = b.databasename" 
   QUEUE "   and b.maxspool     > 0" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2" 
   QUEUE "  with sum(maxspool)  (title '', format 'zzzzz,zzz,zzz,999');" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOAMU - Queue the AmpUsage Report                                 */ 
/*--------------------------------------------------------------------*/ 
DOAMU: 
   amu = 1 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set width 85" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set rtitle 'AMPusage Report'" 
   QUEUE ".export report ddname=rptamu" 
   QUEUE "" 
   QUEUE "locking dbc.ampusage for access" 
   QUEUE "select username     (char(20), title 'User')," 
   QUEUE "       accountname  (char(20), title 'Account')," 
   QUEUE "       sum(cputime) (title 'CPU', format 'zzz,zzz,zzz,zz9')," 
   QUEUE "       sum(diskio)  (title 'I/O', format 'zzz,zzz,zzz,zz9')" 
   QUEUE "  from dbc.ampusage" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOTREE2 - Queue the TREE Report                                   */ 
/*--------------------------------------------------------------------*/ 
DOTREE2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".export ddname=rpttre" 
   QUEUE ".set format on" 
   QUEUE ".set skipline off" 
   QUEUE ".set rtitle 'TREE Diagram from Database "tredb"'" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set width 85" 
   QUEUE ".set suppress on 1, 2, 3, 4, 5, 6" 
   QUEUE "" 
   QUEUE "locking dbc.databases for access" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    ' '             (char(10), title 'lev3')," 
   QUEUE "    ' '             (char(10), title 'lev4')," 
   QUEUE "    ' '             (char(10), title 'lev5')," 
   QUEUE "    ' '             (char(10), title 'lev6')," 
   QUEUE "    ' '             (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"')" 
   QUEUE "UNION" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    b.databasename  (char(10), title 'lev3')," 
   QUEUE "    ' '             (char(10), title 'lev4')," 
   QUEUE "    ' '             (char(10), title 'lev5')," 
   QUEUE "    ' '             (char(10), title 'lev6')," 
   QUEUE "    ' '             (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a," 
   QUEUE "      dbc.databases b" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"'" 
   QUEUE "  and  b.ownername = a.databasename)" 
   QUEUE "UNION" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    b.databasename  (char(10), title 'lev3')," 
   QUEUE "    c.databasename  (char(10), title 'lev4')," 
   QUEUE "    ' '             (char(10), title 'lev5')," 
   QUEUE "    ' '             (char(10), title 'lev6')," 
   QUEUE "    ' '             (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a," 
   QUEUE "      dbc.databases b," 
   QUEUE "      dbc.databases c" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"'" 
   QUEUE "  and  b.ownername = a.databasename" 
   QUEUE "  and  c.ownername = b.databasename)" 
   QUEUE "UNION" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    b.databasename  (char(10), title 'lev3')," 
   QUEUE "    c.databasename  (char(10), title 'lev4')," 
   QUEUE "    d.databasename  (char(10), title 'lev5')," 
   QUEUE "    ' '             (char(10), title 'lev6')," 
   QUEUE "    ' '             (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a," 
   QUEUE "      dbc.databases b," 
   QUEUE "      dbc.databases c," 
   QUEUE "      dbc.databases d" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"'" 
   QUEUE "  and  b.ownername = a.databasename" 
   QUEUE "  and  c.ownername = b.databasename" 
   QUEUE "  and  d.ownername = c.databasename)" 
   QUEUE "UNION" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    b.databasename  (char(10), title 'lev3')," 
   QUEUE "    c.databasename  (char(10), title 'lev4')," 
   QUEUE "    d.databasename  (char(10), title 'lev5')," 
   QUEUE "    e.databasename  (char(10), title 'lev6')," 
   QUEUE "    ' '             (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a," 
   QUEUE "      dbc.databases b," 
   QUEUE "      dbc.databases c," 
   QUEUE "      dbc.databases d," 
   QUEUE "      dbc.databases e" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"'" 
   QUEUE "  and  b.ownername = a.databasename" 
   QUEUE "  and  c.ownername = b.databasename" 
   QUEUE "  and  d.ownername = c.databasename" 
   QUEUE "  and  e.ownername = d.databasename)" 
   QUEUE "UNION" 
   QUEUE "sel a.ownername     (char(10), title 'lev1')," 
   QUEUE "    a.databasename  (char(10), title 'lev2')," 
   QUEUE "    b.databasename  (char(10), title 'lev3')," 
   QUEUE "    c.databasename  (char(10), title 'lev4')," 
   QUEUE "    d.databasename  (char(10), title 'lev5')," 
   QUEUE "    e.databasename  (char(10), title 'lev6')," 
   QUEUE "    f.databasename  (char(10), title 'lev7')" 
   QUEUE "from  dbc.databases a," 
   QUEUE "      dbc.databases b," 
   QUEUE "      dbc.databases c," 
   QUEUE "      dbc.databases d," 
   QUEUE "      dbc.databases e," 
   QUEUE "      dbc.databases f" 
   QUEUE "where (a.ownername = '"tredb"'" 
   QUEUE "  and  a.databasename <> '"tredb"'" 
   QUEUE "  and  b.ownername = a.databasename" 
   QUEUE "  and  c.ownername = b.databasename" 
   QUEUE "  and  d.ownername = c.databasename" 
   QUEUE "  and  e.ownername = d.databasename" 
   QUEUE "  and  f.ownername = e.databasename)" 
   QUEUE " order by 1, 2, 3, 4, 5, 6, 7;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOUSR2 - Create User Rights SQL                                   */ 
/*--------------------------------------------------------------------*/ 
DOUSR2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set supress on 1, 2" 
   QUEUE ".set rtitle 'Access Rights for User "usrin"'" 
   QUEUE ".set width 90" 
   QUEUE ".export report ddname=rptrgt" 
   QUEUE "select databasename     (title 'Database', char(20))," 
   QUEUE "       tablename        (title 'TVM', char(30))," 
   QUEUE "       accessright      (title 'Privilege')," 
   QUEUE "       grantorname      (title 'Grantor', char(20))" 
   QUEUE "  from dbc.allrights" 
   QUEUE " where username = '"usrin"'" 
   QUEUE " order by 1, 2, 3;" 
   QUEUE ".export reset" 
   RETURN 


/*--------------------------------------------------------------------*/ 
/*  DODBHELP2 - Create Help Database Report SQL                       */ 
/*--------------------------------------------------------------------*/ 
DODBHELP2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set null '* none defined *'" 
   QUEUE ".set format on" 
   QUEUE ".set rtitle 'TVM Help for Database "dbhin"'" 
   QUEUE ".set width 132" 
   QUEUE ".export report ddname=dhprpt" 
   QUEUE "select tablename        (title 'Name', char(30))," 
   QUEUE "       tablekind        (title 'Kind')," 
   QUEUE "       protectiontype   (title 'FB//NoFB')," 
   QUEUE "       journalflag      (title 'Journal')," 
   QUEUE "       commentstring    (title 'Comments', char(70))" 
   QUEUE "  from dbc.tables" 
   QUEUE " where databasename = '"dbhin"'" 
   QUEUE " order by 1;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOV2 - Create User Database Rights SQL                            */ 
/*--------------------------------------------------------------------*/ 
DOV2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1, 2, 3" 
   QUEUE ".set rtitle 'Privileges Granted on Database "dbvin"'" 
   QUEUE ".set width 90" 
   QUEUE ".export report ddname=rptdrgt" 
   QUEUE "select username         (title 'User', char(20))," 
   QUEUE "       tablename        (title 'TVM',  char(30))," 
   QUEUE "       accessright      (title 'Privilege')," 
   QUEUE "       grantorname      (title 'Grantor', char(20))" 
   QUEUE "  from dbc.allrights" 
   QUEUE " where databasename = '"dbvin"'" 
   QUEUE " order by 1, 2, 3;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOPCT2 - Create PCT Info SQL                                      */ 
/*--------------------------------------------------------------------*/ 
DOPCT2: 
   pct = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Data Skew by Table for Database "pctdb"'" 
   QUEUE ".set width 80" 
   QUEUE ".export report ddname=rptpct" 
   QUEUE "select databasename     (title 'Database', char(20))," 
   QUEUE "       tablename        (title 'Table',  char(30))," 
   QUEUE "       ( (max(currentperm)-min(currentperm) ) /" 
   QUEUE "       nullifzero(min(currentperm)) ) * 100" 
   QUEUE "(title 'AMP Percent Skew//Least to Most full//(max-min)/min'" 
   QUEUE "       , format 'zzz,zzz.99%')" 
   QUEUE "  from dbc.tablesize" 
   QUEUE " where databasename = '"pctdb"'" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOCSPOOL2 - Create Spool SQL                                      */ 
/*--------------------------------------------------------------------*/ 
DOCSPOOL2: 
   cspl = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Current Spool Report'" 
   QUEUE ".set width 80" 
   QUEUE ".export report ddname=rptspl" 
   QUEUE "select databasename      (title 'User', char(30))," 
   QUEUE "       sum(currentspool) (title 'Current//Spool')" 
   QUEUE "  from dbc.diskspace" 
   QUEUE " group by 1" 
   QUEUE " order by 2 desc;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOEVL2 - Create Event LIKE SQL                                    */ 
/*--------------------------------------------------------------------*/ 
DOEVL2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set rtitle 'Reporting on an Event "evntx"'" 
   QUEUE ".set width 110" 
   QUEUE ".export report ddname=rptevl" 
   QUEUE "locking dbc.errorlog for access" 
   QUEUE "select errdate, errtime, text" 
   QUEUE "  from dbc.errorlog" 
   QUEUE " where ((errdate = "sdate" and errtime >= "stime")" 
   QUEUE "    or  (errdate > "sdate"))" 
   QUEUE "   and ((errdate = "edate" and errtime <= "etime")" 
   QUEUE "    or  (errdate < "edate"))" 
   IF evntq = 1 THEN 
      QUEUE "   and event     = "evnt"" 
   ELSE 
      QUEUE "   and event between "evnt1" and "evnt2"" 
   QUEUE "   and text not = ''" 
   QUEUE " order by errdate, errtime, linenumber;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOFB2 - Create FB Info SQL                                        */ 
/*--------------------------------------------------------------------*/ 
DOFB2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Fallback Status for Tables in "fbdb"'" 
   QUEUE ".set width 72" 
   QUEUE ".export report ddname=rptfb" 
   QUEUE "select databasename," 
   QUEUE "       tablename," 
   QUEUE "    protectiontype (title 'Fallback (F)//No Fallback (N)')," 
   QUEUE "       journalflag (title 'Journaling//(Before/After)')" 
   QUEUE "  from dbc.tables" 
   QUEUE " where databasename = '"fbdb"'" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOINDX2 - Create Index Info SQL                                   */ 
/*--------------------------------------------------------------------*/ 
DOINDX2: 
   QUEUE ""; 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1, 2" 
   QUEUE ".set skipline off" 
   QUEUE ".set skipline on 1" 
   QUEUE ".set rtitle 'Index Status for Tables in "ixdb"'" 
   QUEUE ".set width 72" 
   QUEUE ".export report ddname=rptindx" 
   QUEUE "locking dbc.indices for access" 
   QUEUE "select databasename," 
   QUEUE "       tablename," 
   QUEUE "       sum(index(uniqueflag, 'N'))  (title '# NUSIs')," 
   QUEUE "       sum(index(uniqueflag, 'Y'))  (title '#  USIs')" 
   QUEUE "  from dbc.indices" 
   QUEUE " where databasename = '"ixdb"'" 
   QUEUE "   and indextype    = 'S'" 
   QUEUE "   and columnposition = 1" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DODTL2 - Create DTL Info  SQL for Database                        */ 
/*--------------------------------------------------------------------*/ 
DODTL2: 
   dtl2 = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 80" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set rtitle 'Data hashing by AMP for Database "dtldb"'" 
   QUEUE ".export report ddname=rptstl2" 
   QUEUE "select databasename     (title 'Database', char(30))," 
   QUEUE "       amp              (format 'zzz-9')," 
   QUEUE "       currentperm      (format 'zzz,zzz,zzz,zzz')" 
   QUEUE "  from dbc.diskspace" 
   QUEUE " where databasename = '"dtldb"'" 
   QUEUE "  with sum(currentperm) (title '')" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DODTL3 - Create DTL Info SQL for Table                            */ 
/*--------------------------------------------------------------------*/ 
DODTL3: 
   dtl3 = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 80" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set rtitle 'Data hashing by AMP for Table "dtltb"'" 
   QUEUE ".export report ddname=rptstl3" 
   QUEUE "select databasename     (title 'Database', char(30))," 
   QUEUE "       tablename        (Title 'Table',    char(30))," 
   QUEUE "       amp              (format 'zzz-9')," 
   QUEUE "       currentperm      (format 'zzz,zzz,zzz,zzz')" 
   QUEUE "  from dbc.tablesize" 
   QUEUE " where tablename = '"dtltb"'" 
   QUEUE "  with sum(currentperm) (title 'Total:')" 
   QUEUE " order by 1, 2, 3;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOSUM2 - Create Summary Perm for DB Tables                        */ 
/*--------------------------------------------------------------------*/ 
DOSUM2: 
   prmsum = 1 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 80" 
   QUEUE ".set foldline on 1" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set rtitle 'Data Perm for Tables if Database "sumdb"'" 
   QUEUE ".export report ddname=rptsum" 
   QUEUE "select databasename     (title 'Database', char(20))," 
   QUEUE "       tablename        (title 'Table',    char(20))," 
   QUEUE "       sum(currentperm) (format 'zzz,zzz,zzz,zzz'," 
   QUEUE "                         title 'Perm')" 
   QUEUE "  from dbc.tablesize" 
   QUEUE " where databasename = '"sumdb"'" 
   QUEUE "  with sum(currentperm)" 
   QUEUE " group by 1, 2" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOACCT2 - Create User Account Info SQL                            */ 
/*--------------------------------------------------------------------*/ 
DOACCT2: 
   QUEUE "" 
   QUEUE ".export report ddname=rptacct" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set rtitle 'General User Information for "actusr"'" 
   QUEUE ".set width 85" 
   QUEUE ".set null '* none defined *'" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set foldline on all" 
   QUEUE ".set sidetitles" 
   QUEUE "locking dbc.databases for access" 
   QUEUE "select '     '             (title '     ')," 
   QUEUE "       ownername           (title '  Owner...............')," 
   QUEUE "       creatorname         (title '  Creator.............')," 
   QUEUE "       accountname         (title '  Default Account.....')," 
   QUEUE "       journalflag         (title '  Journaling..........')," 
   QUEUE "       protectiontype      (title '  FB or No FB.........')," 
   QUEUE "       permspace           (title '  Max Perm............')," 
   QUEUE "       spoolspace          (title '  Max Spool...........')," 
   QUEUE "       substr(commentstring, 1, 50)" 
   QUEUE "                           (title '  Comment line 1......')," 
   QUEUE "       substr(commentstring, 51, 100)" 
   QUEUE "                           (title '  Comment line 2......')," 
   QUEUE "       substr(commentstring, 101, 150)" 
   QUEUE "                           (title '  Comment line 3......')," 
   QUEUE "       substr(commentstring, 151, 200)" 
   QUEUE "                           (title '  Comment line 4......')," 
   QUEUE "       substr(commentstring, 201, 255)" 
   QUEUE "                           (title '  Comment line 5......')" 
   QUEUE "  from dbc.databases" 
   QUEUE " where databasename = '"actusr"';" 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set suppress on 1" 
   QUEUE ".set null '-'" 
   QUEUE ".set rtitle 'Account Information for User "actusr"'" 
   QUEUE "select username         (title 'User', char(30))," 
   QUEUE "       accountname      (title 'Account//Name')" 
   QUEUE "  from dbc.accountinfo" 
   QUEUE " where username = '"actusr"'" 
   QUEUE " order by 1, 2;" 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DORES2 - Queue the ResUsage Report SQL                            */ 
/*--------------------------------------------------------------------*/ 
DORES2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE "database "resdbdef";" 
   QUEUE ".export report ddname=rptres" 
   QUEUE "" 
   IF INDEX(resin,'A') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResNode    ("sdate","edate","stime","etime");" 
      ELSE 
         QUEUE "exec dbc.ResOneNode ("sdate","edate","stime","etime",", 
                                     resresp");" 

   IF INDEX(resin,'C') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResNetByNode  ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResNetOneNode ("sdate","edate","stime","etime",", 
                                        resresp");" 

   IF INDEX(resin,'D') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResCPUByAMP ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResCPUByAMPOneNode ("sdate","edate","stime","etime",", 
                                             resresp");" 

   IF INDEX(resin,'E') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResCPUByPE ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResCPUByPEOneNode ("sdate","edate","stime","etime",", 
                                            resresp");" 

   IF INDEX(resin,'F') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResCPUByNode ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResCPUOneNode ("sdate","edate","stime","etime",", 
                                        resresp");" 

   IF INDEX(resin,'G') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResHostByLink ("sdate","edate","stime","etime");" 
      ELSE 
         QUEUE "exec dbc.ResHostOneNode ("sdate","edate","stime","etime",", 
                                        resresp");" 

   IF INDEX(resin,'H') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResLdvByNode ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResLdvOneNode ("sdate","edate","stime","etime",", 
                                        resresp");" 

   IF INDEX(resin,'I') > 0 THEN 
      IF resnumflg = 0 THEN 
         QUEUE "exec dbc.ResMemMgmtByNode ("sdate","edate","stime","etime",,);" 
      ELSE 
         QUEUE "exec dbc.ResMemMgmtOneNode ("sdate","edate","stime","etime",", 
                                        resresp");" 

   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOD2W2 - Queue the Day-of-Week SQL                                */ 
/*--------------------------------------------------------------------*/ 
DOD2W2: 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".export report ddname=rptd2w" 
   QUEUE ".set rtitle 'Date to Day-of-Week Conversion'" 
   QUEUE ".set width 80" 
   QUEUE "" 
   i = 0 
   DO 3 
      IF dconv.i = ' '  THEN NOP 
      ELSE 
         DO 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Monday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 0" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Tuesday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 1" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Wednesday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 2" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Thursday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 3" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Friday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 4" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Saturday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 5" 
         QUEUE "UNION" 
         QUEUE "select "dconv.i" (title 'Date')," 
         QUEUE "       'Sunday'  (title 'Day', char(10))" 
         QUEUE "  from dbc.databases" 
         QUEUE " where (("dconv.i" (DATE))-(000101 (DATE))) MOD 7 = 6;" 
         END 
      i = i + 1 
      END 
   QUEUE ".export reset" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DODDL2 - Queue the DDL Report SQL                                 */ 
/*--------------------------------------------------------------------*/ 
DODDL2: 
   tvmkind = tvmkind" " 
   QUEUE "" 
   QUEUE ".set defaults" 
   QUEUE ".export data ddname=rptddl" 
   QUEUE "" 
   QUEUE "select '"logonstring"'       (char(50));" 
   QUEUE "select 'database "dbname";'  (char(40));" 
   QUEUE "" 
   IF INDEX('T ', tvmkind) > 0 THEN 
      DO 
      QUEUE "select 'show table '      (char(11))," 
      QUEUE "       tablename          (char(30))," 
      QUEUE "       ';'                (char(01))" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"dbname"'" 
      QUEUE "   and tablekind = 't'" 
      END 
   IF tvmkind = '' THEN 
      QUEUE "UNION" 
   IF INDEX('V ', tvmkind) > 0 THEN 
      DO 
      QUEUE "select 'show view  '      (char(11))," 
      QUEUE "       tablename          (char(30))," 
      QUEUE "       ';'                (char(01))" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"dbname"'" 
      QUEUE "   and tablekind = 'v'" 
      END 
   IF tvmkind = '' THEN 
      QUEUE "UNION" 
   IF INDEX('M ', tvmkind) > 0 THEN 
      DO 
      QUEUE "select 'show macro '      (char(11))," 
      QUEUE "       tablename          (char(30))," 
      QUEUE "       ';'                (char(01))" 
      QUEUE "  from dbc.tables" 
      QUEUE " where databasename = '"dbname"'" 
      QUEUE "   and tablekind = 'm'" 
      END 
   QUEUE " order by 1, 2;" 
   QUEUE "" 
   QUEUE "select '.quit'            (char(05));" 
   QUEUE "" 
   QUEUE ".export reset" 
   QUEUE ".run ddname=rptddl" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*----------------------------- SUBROUTINES --------------------------*/ 
/*--------------------------------------------------------------------*/ 

/*--------------------------------------------------------------------*/ 
/*  DOSLOT - Queue the ResUse SQL for timeslots                       */ 
/*--------------------------------------------------------------------*/ 
DOSLOT: 
   ARG prccode 
   QUEUE ".set defaults" 
   QUEUE ".set format on" 
   QUEUE ".set width 80" 
   QUEUE ".set separator 1" 
   QUEUE ".set null as '-'" 
   QUEUE ".set skipline on 3" 
   QUEUE ".set pagebreak on 1" 
   IF prccode = 'A' THEN 
      QUEUE ".set rtitle 'ResUsages by Day and Time Slot (AMPs)'" 
   IF prccode = 'I' THEN 
      QUEUE ".set rtitle 'ResUsages by Day and Time Slot (IFPs)'" 
   IF prccode = 'C' THEN 
      QUEUE ".set rtitle 'ResUsages by Day and Time Slot (COPs)'" 
      QUEUE "select" 
      QUEUE "    thedate," 
      QUEUE "    thetime," 
      QUEUE "    proc," 
      QUEUE "average((hits - schidle) * 100 / hits)" 
      QUEUE "              (title 'Avg//CPU', format 'zz9%')," 
      QUEUE "maximum((hits - schidle) * 100 / hits)" 
      QUEUE "              (title 'Avg//CPU', format 'zz9%')" 
   /*------------------------------------------*/ 
   /*  Value of proccode will allways be       */ 
   /*  equal to 'A', 'I' or 'C' never ''       */ 
   /*------------------------------------------*/ 
   SELECT 
      WHEN prccode = 'I'  THEN NOP 
      WHEN prccode = 'C'  THEN NOP 
      OTHERWISE 
         DO 
         QUEUE ",average((disk0seek+disk1seek+disk2seek+disk3seek" 
         QUEUE "        + disk0wait+disk1wait+disk2wait+disk3wait" 
         QUEUE "        + disk0xfer+disk1xfer+disk2xfer+disk3xfer)" 
         QUEUE "        * 100.0 / hits)" 
         QUEUE "          (title 'Avg//Disk', format 'zz9')" 
         QUEUE ",maximum((disk0seek+disk1seek+disk2seek+disk3seek" 
         QUEUE "        + disk0wait+disk1wait+disk2wait+disk3wait" 
         QUEUE "        + disk0xfer+disk1xfer+disk2xfer+disk3xfer)" 
         QUEUE "        * 100.0 / hits)" 
         QUEUE "          (title 'Max//Disk', format 'zz9')" 
       QUEUE ",(average((swapreads + swapwrites) / 0.06 / hits) * 100)" 
         QUEUE "        / nullifzero(average((disk0reads + disk1reads" 
         QUEUE "          + disk2reads + disk3reads + disk0writes" 
         QUEUE "          + disk1writes + disk2writes + disk3writes)" 
         QUEUE "            / 0.06 / hits))" 
         QUEUE "          (title 'Swap//as %//I/O', format 'zz9%')" 
         END 
      END 
   SELECT 
      WHEN prccode = 'A'  THEN NOP 
      OTHERWISE 
         DO 
         QUEUE ",average(hostbusy * 100.0 / hits)" 
         QUEUE "         (title 'Avg//CIC//Busy', format 'zz9%')" 
         QUEUE ",maximum(hostbusy * 100.0 / hits)" 
         QUEUE "         (title 'Max//CIC//Busy', format 'zz9%')" 
         END 
      END 
   QUEUE ",average(congestions * 100.0 / hits + 0.499)" 
   QUEUE "         (title 'Avg//Cong', format 'zz9%')" 
   QUEUE ",maximum(congestions * 1000.0 / hits + 0.499)" 
   QUEUE "         (title 'Max//Cong', format 'zz9%')" 
   QUEUE ",average((netanotidle + netbnotidle) / 2.0 * 100.0 / hits)" 
   QUEUE "         (title 'Avg//Ynet//Busy', format 'zz9%')" 
   QUEUE ",maximum((netanotidle + netbnotidle) / 2.0 * 100.0 / hits)" 
   QUEUE "         (title 'Max//Ynet//Busy', format 'zz9%')" 
   QUEUE "  from dbc.resusage" 
   QUEUE " where ((thedate >= "sdate" and thedate <= "edate")" 
   QUEUE "   and  (thetime >= "stime" and thetime <= "etime"))" 
   IF prccode = 'A'  THEN QUEUE "   and  proc like '%AMP%'" 
   IF prccode = 'I'  THEN QUEUE "   and  proc like '%IFP%'" 
   IF prccode = 'C'  THEN QUEUE "   and  proc like '%COP%'" 
   QUEUE "   and  secs = 600" 
   QUEUE " group by thedate, thetime, proc, secs" 
   QUEUE " order by proc, thedate, thetime;" 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  GETDATE  Get the date in DBC format                               */ 
/*--------------------------------------------------------------------*/ 
GETDATE: 
   dater = DATE('O') 
   PARSE UPPER VAR dater yy "/" mm "/" dd 
   dater = yy""mm""dd 
   datez = mm"/"dd"/"yy 
   timez = TIME() 
   RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOHELP  Display the HELP Info                                     */ 
/*--------------------------------------------------------------------*/ 
DOHELP: 
  "CLEAR" 
  DO i = 1 TO SOURCELINE() 
     IF SUBSTR(SOURCELINE(i), 1, 2) = '/*' THEN 
        SAY SOURCELINE(i) 
     ELSE 
        LEAVE i 
     END 
  RETURN 

/*--------------------------------------------------------------------*/ 
/*  DOHELP2  Display the Help Info and continue.                      */ 
/*--------------------------------------------------------------------*/ 
DOHELP2: 
  "CLEAR" 
  DO FOREVER 
     CALL DOHELP 
     SAY "You may enter QUIT at any time to leave this exec." 
     SAY "Enter Report/Date-Time options: (Currently:" DATE('O'), 
             "at" TIME() ")" 
     PULL args 
     PARSE VAR args rpt sdate edate stime etime logon_id . 
     IF rpt   = "QUIT" THEN 
        EXIT 
     IF rpt   = "EXIT" THEN 
        EXIT 
     "CLEAR" 
     IF args <> '' THEN 
        LEAVE 
     END 
   RETURN 

/*--------------------------------------------------------------------*/ 
/* EDITIT (string, char) - Place slashes/colons in date or time       */ 
/*--------------------------------------------------------------------*/ 
EDITIT: 
   ARG editstr, editchar 
   PARSE VAR editstr 1 yy 3 mm 5 dd 7 
   RETURN yy""editchar""mm""editchar""dd 


/*--------------- LOAD BTEQ VARIABLES ---------------*/ 
LoadBTEQ: 
   config_name   = "'"USERID()".BTEQ.CONFIG'" 
   DO UNTIL pre_exist 
      pre_exist = (LISTDSI(config_name) = 0) 
      IF pre_exist THEN DO 
         "ALLOC DDN(config) SHR DSN("config_name") REUSE" 
         "NEWSTACK" 
         "EXECIO * DISKR config (FINIS)" 
         DO QUEUED() 
            PARSE PULL config_param 
            INTERPRET config_param 
            END 
         "DELSTACK" 
         "FREE DDN(config)" 
         END 
      ELSE 
         CALL "BTEQINIT" config_name 
      END 
   RETURN 

ChooseLogon: 
   SAY "Enter LOGON Option:" 
   DO i = 1 TO logon.0 
      SAY "    "i".  "logon.i.desc 
      END 
   DO UNTIL (logon_id > 0) & (logon_id <= logon.0) 
      PARSE EXTERNAL logon_id 
      END 
   RETURN logon_id 

FindLogon: 
   PARSE UPPER ARG UserID 
   DO i = 1 to logon.0 
      PARSE UPPER VAR logon.i.desc xx 
      IF INDEX(xx, UserID) <> 0 THEN 
         RETURN i 
      END 
   RETURN 0 

ChooseRunOption: 
   SAY "Enter Run Option:" 
   SAY "    1.  Run in Foreground" 
   SAY "    2.  Run in Background" 
   SAY "    3.  Build Background Job and EDIT" 
   DO UNTIL (run_optn > 0) & (run_optn <= 3) 
      PARSE EXTERNAL run_optn 
      END 
   RETURN run_optn 
